@@ -16,7 +16,8 @@ def create_app(config=None):
     app = falcon.asgi.App(middleware=[cache])
     app.add_route('/images', images)
     app.add_route('/images/{image_id:uuid}.jpeg', images, suffix='image')
-    app.add_route('/thumbnails/{image_id:uuid}/{width:int}x{height:int}.jpeg',
-                  thumbnails)
+    app.add_route(
+        '/thumbnails/{image_id:uuid}/{width:int}x{height:int}.jpeg', thumbnails
+    )
 
     return app
