@@ -8,7 +8,6 @@ import msgpack
 
 
 class Resource:
-
     def __init__(self, image_store):
         self._image_store = image_store
 
@@ -16,9 +15,9 @@ class Resource:
         doc = {
             'images': [
                 {
-                    'href': '/images/1eaf6ef1-7f2d-4ecc-a8d5-6e8adba7cc0e.png'
-                }
-            ]
+                    'href': '/images/1eaf6ef1-7f2d-4ecc-a8d5-6e8adba7cc0e.png',
+                },
+            ],
         }
 
         resp.data = msgpack.packb(doc, use_bin_type=True)
