@@ -20,7 +20,6 @@ directly from the `testing` package::
     from falcon import testing
 
     wsgi_environ = testing.create_environ()
-
 """
 
 import asyncio
@@ -242,8 +241,8 @@ class ASGIRequestEventEmitter:
 
                 return event
 
-        chunk = self._body[:self._chunk_size]
-        self._body = self._body[self._chunk_size:] or None
+        chunk = self._body[: self._chunk_size]
+        self._body = self._body[self._chunk_size :] or None
 
         if chunk:
             event['body'] = bytes(chunk)
@@ -294,15 +293,17 @@ class ASGIResponseEventCollector:
         ValueError: Invalid event name or field value.
     """
 
-    _LIFESPAN_EVENT_TYPES = frozenset([
-        'lifespan.startup.complete',
-        'lifespan.startup.failed',
-        'lifespan.shutdown.complete',
-        'lifespan.shutdown.failed',
-    ])
+    _LIFESPAN_EVENT_TYPES = frozenset(
+        [
+            'lifespan.startup.complete',
+            'lifespan.startup.failed',
+            'lifespan.shutdown.complete',
+            'lifespan.shutdown.failed',
+        ]
+    )
 
-    _HEADER_NAME_RE = re.compile(br'^[a-zA-Z][a-zA-Z0-9\-_]*$')
-    _BAD_HEADER_VALUE_RE = re.compile(br'[\000-\037]')
+    _HEADER_NAME_RE = re.compile(rb'^[a-zA-Z][a-zA-Z0-9\-_]*$')
+    _BAD_HEADER_VALUE_RE = re.compile(rb'[\000-\037]')
 
     def __init__(self):
         self.events = []
@@ -561,7 +562,9 @@ class ASGIWebSocketSimulator:
 
         # NOTE(kgriffs): Even if the key is present, it may be None
         if text is None:
-            raise falcon_errors.PayloadTypeError('Expected TEXT payload but got BINARY instead')
+            raise falcon_errors.PayloadTypeError(
+                'Expected TEXT payload but got BINARY instead'
+            )
 
         return text
 
@@ -583,7 +586,9 @@ class ASGIWebSocketSimulator:
 
         # NOTE(kgriffs): Even if the key is present, it may be None
         if data is None:
-            raise falcon_errors.PayloadTypeError('Expected BINARY payload but got TEXT instead')
+            raise falcon_errors.PayloadTypeError(
+                'Expected BINARY payload but got TEXT instead'
+            )
 
         return data
 
@@ -616,6 +621,7 @@ class ASGIWebSocketSimulator:
 
         if not self.__msgpack:
             import msgpack
+
             self.__msgpack = msgpack
 
         return self.__msgpack
@@ -720,7 +726,9 @@ class ASGIWebSocketSimulator:
                 self._state = _WebSocketState.DENIED
 
                 desired_code = event.get('code', WSCloseCode.NORMAL)
-                if desired_code == WSCloseCode.SERVER_ERROR or (3000 <= desired_code < 4000):
+                if desired_code == WSCloseCode.SERVER_ERROR or (
+                    3000 <= desired_code < 4000
+                ):
                     # NOTE(kgriffs): Pass this code through since it is a
                     #   special code we have set in the framework to trigger
                     #   different raised error types or to pass through a
@@ -793,7 +801,7 @@ def get_encoding_from_headers(headers):
     content_type, params = cgi.parse_header(content_type)
 
     if 'charset' in params:
-        return params['charset'].strip("'\"")
+        return params['charset'].strip('\'"')
 
     # NOTE(kgriffs): Added checks for text/event-stream and application/json
     if content_type in ('text/event-stream', 'application/json'):
@@ -834,14 +842,24 @@ def rand_string(min, max) -> str:
 
     int_gen = random.randint
     string_length = int_gen(min, max)
-    return ''.join([chr(int_gen(ord(' '), ord('~')))
-                    for __ in range(string_length)])
+    return ''.join([chr(int_gen(ord(' '), ord('~'))) for __ in range(string_length)])
 
 
-def create_scope(path='/', query_string='', method='GET', headers=None,
-                 host=DEFAULT_HOST, scheme=None, port=None, http_version='1.1',
-                 remote_addr=None, root_path=None, content_length=None,
-                 include_server=True, cookies=None) -> Dict[str, Any]:
+def create_scope(
+    path='/',
+    query_string='',
+    method='GET',
+    headers=None,
+    host=DEFAULT_HOST,
+    scheme=None,
+    port=None,
+    http_version='1.1',
+    remote_addr=None,
+    root_path=None,
+    content_length=None,
+    include_server=True,
+    cookies=None,
+) -> Dict[str, Any]:
 
     """Create a mock ASGI scope ``dict`` for simulating HTTP requests.
 
@@ -867,7 +885,7 @@ def create_scope(path='/', query_string='', method='GET', headers=None,
                     f'falcon-client/{falcon.__version__}'
 
         host(str): Hostname for the request (default ``'falconframework.org'``).
-            This also determines the the value of the Host header in the
+            This also determines the value of the Host header in the
             request.
         scheme (str): URL scheme, either ``'http'`` or ``'https'``
             (default ``'http'``)
@@ -959,16 +977,27 @@ def create_scope(path='/', query_string='', method='GET', headers=None,
     if method == 'OPTIONS' and cookies is not None:
         cookies = None
 
-    _add_headers_to_scope(scope, headers, content_length, host,
-                          port, scheme, http_version, cookies)
+    _add_headers_to_scope(
+        scope, headers, content_length, host, port, scheme, http_version, cookies
+    )
 
     return scope
 
 
-def create_scope_ws(path='/', query_string='', headers=None,
-                    host=DEFAULT_HOST, scheme=None, port=None, http_version='1.1',
-                    remote_addr=None, root_path=None, include_server=True,
-                    subprotocols=None, spec_version='2.1') -> Dict[str, Any]:
+def create_scope_ws(
+    path='/',
+    query_string='',
+    headers=None,
+    host=DEFAULT_HOST,
+    scheme=None,
+    port=None,
+    http_version='1.1',
+    remote_addr=None,
+    root_path=None,
+    include_server=True,
+    subprotocols=None,
+    spec_version='2.1',
+) -> Dict[str, Any]:
 
     """Create a mock ASGI scope ``dict`` for simulating WebSocket requests.
 
@@ -993,7 +1022,7 @@ def create_scope_ws(path='/', query_string='', headers=None,
                     f'falcon-client/{falcon.__version__}'
 
         host(str): Hostname for the request (default ``'falconframework.org'``).
-            This also determines the the value of the Host header in the
+            This also determines the value of the Host header in the
             request.
         scheme (str): URL scheme, either ``'ws'`` or ``'wss'``
             (default ``'ws'``)
@@ -1039,11 +1068,23 @@ def create_scope_ws(path='/', query_string='', headers=None,
     return scope
 
 
-def create_environ(path='/', query_string='', http_version='1.1',
-                   scheme='http', host=DEFAULT_HOST, port=None,
-                   headers=None, app=None, body='', method='GET',
-                   wsgierrors=None, file_wrapper=None, remote_addr=None,
-                   root_path=None, cookies=None) -> Dict[str, Any]:
+def create_environ(
+    path='/',
+    query_string='',
+    http_version='1.1',
+    scheme='http',
+    host=DEFAULT_HOST,
+    port=None,
+    headers=None,
+    app=None,
+    body='',
+    method='GET',
+    wsgierrors=None,
+    file_wrapper=None,
+    remote_addr=None,
+    root_path=None,
+    cookies=None,
+) -> Dict[str, Any]:
 
     """Create a mock PEP-3333 environ ``dict`` for simulating WSGI requests.
 
@@ -1155,14 +1196,13 @@ def create_environ(path='/', query_string='', http_version='1.1',
         'RAW_URI': '/',
         'SERVER_NAME': host,
         'SERVER_PORT': port,
-
         'wsgi.version': (1, 0),
         'wsgi.url_scheme': scheme,
         'wsgi.input': body,
         'wsgi.errors': wsgierrors or sys.stderr,
         'wsgi.multithread': False,
         'wsgi.multiprocess': True,
-        'wsgi.run_once': False
+        'wsgi.run_once': False,
     }
 
     # NOTE(kgriffs): It has been observed that WSGI servers do not always
@@ -1345,8 +1385,9 @@ def _add_headers_to_environ(env, headers):
     env.setdefault('HTTP_USER_AGENT', DEFAULT_UA)
 
 
-def _add_headers_to_scope(scope, headers, content_length, host,
-                          port, scheme, http_version, cookies):
+def _add_headers_to_scope(
+    scope, headers, content_length, host, port, scheme, http_version, cookies
+):
     found_ua = False
     prepared_headers = []
 
@@ -1410,7 +1451,9 @@ def _fixup_http_version(http_version) -> str:
 
 
 def _make_cookie_values(cookies: Dict) -> str:
-    return '; '.join([
-        '{}={}'.format(key, cookie.value if hasattr(cookie, 'value') else cookie)
-        for key, cookie in cookies.items()
-    ])
+    return '; '.join(
+        [
+            '{}={}'.format(key, cookie.value if hasattr(cookie, 'value') else cookie)
+            for key, cookie in cookies.items()
+        ]
+    )
