@@ -21,34 +21,37 @@ utilities for simulating and validating HTTP requests.
 try:
     import testtools as unittest
 except ImportError:  # pragma: nocover
-    import unittest
+    import unittest  # type: ignore
 
 import falcon
 import falcon.request
+
+# TODO hoist for backwards compat. Remove in falcon 4.
+from falcon.testing.client import Result  # NOQA
 from falcon.testing.client import TestClient
-from falcon.testing.client import Result  # NOQA - hoist for backwards compat
 
 
 class TestCase(unittest.TestCase, TestClient):
-    """Extends :py:mod:`unittest` to support WSGI functional testing.
+    """Extends :py:mod:`unittest` to support WSGI/ASGI functional testing.
 
     Note:
         If available, uses :py:mod:`testtools` in lieu of
         :py:mod:`unittest`.
 
     This base class provides some extra plumbing for unittest-style
-    test cases, to help simulate WSGI calls without having to spin up
-    an actual web server. Various simulation methods are derived
-    from :py:class:`falcon.testing.TestClient`.
+    test cases, to help simulate WSGI or ASGI requests without having
+    to spin up an actual web server. Various simulation methods are
+    derived from :py:class:`falcon.testing.TestClient`.
 
     Simply inherit from this class in your test case classes instead of
     :py:class:`unittest.TestCase` or :py:class:`testtools.TestCase`.
 
     Attributes:
-        app (object): A WSGI application to target when simulating
-            requests (default: ``falcon.API()``). When testing your
+        app (object): A WSGI or ASGI application to target when simulating
+            requests (defaults to ``falcon.App()``). When testing your
             application, you will need to set this to your own instance
-            of ``falcon.API``. For example::
+            of :class:`falcon.App` or :class:`falcon.asgi.App`. For
+            example::
 
                 from falcon import testing
                 import myapp
@@ -60,50 +63,23 @@ class TestCase(unittest.TestCase, TestClient):
 
                         # Assume the hypothetical `myapp` package has a
                         # function called `create()` to initialize and
-                        # return a `falcon.API` instance.
+                        # return a `falcon.App` instance.
                         self.app = myapp.create()
 
 
                 class TestMyApp(MyTestCase):
                     def test_get_message(self):
-                        doc = {u'message': u'Hello world!'}
+                        doc = {'message': 'Hello world!'}
 
                         result = self.simulate_get('/messages/42')
                         self.assertEqual(result.json, doc)
-
-        api (object): Deprecated alias for ``app``
-        api_class (callable): Deprecated class variable; will be
-            removed in a future release.
     """
 
-    api_class = None
-
-    @property
-    def api(self):
-        return self.app
-
-    @api.setter
-    def api(self, value):
-        self.app = value
-
     def setUp(self):
         super(TestCase, self).setUp()
 
-        if self.api_class is None:
-            app = falcon.API()
-        else:
-            app = self.api_class()
+        app = falcon.App()
 
         # NOTE(kgriffs): Don't use super() to avoid triggering
         # unittest.TestCase.__init__()
         TestClient.__init__(self, app)
-
-        # Reset to simulate "restarting" the WSGI container
-        falcon.request._maybe_wrap_wsgi_stream = True
-
-    # NOTE(warsaw): Pythons earlier than 2.7 do not have a
-    # self.assertIn() method, so use this compatibility function
-    # instead.
-    if not hasattr(unittest.TestCase, 'assertIn'):  # pragma: nocover
-        def assertIn(self, a, b):
-            self.assertTrue(a in b)
