@@ -21,7 +21,6 @@ framework itself. These functions are hoisted into the front-door
     import falcon
 
     now = falcon.http_now()
-
 """
 
 import datetime
@@ -29,12 +28,13 @@ import functools
 import http
 import inspect
 import re
-import sys
 import unicodedata
 
 from falcon import status_codes
 from falcon.constants import PYPY
+from falcon.constants import PYTHON_VERSION
 from falcon.uri import encode_value
+
 # NOTE(vytas): Hoist `deprecated` here since it is documented as part of the
 # public Falcon interface.
 from .deprecation import deprecated
@@ -89,8 +89,7 @@ def _lru_cache_nop(*args, **kwargs):  # pragma: nocover
 
 
 # NOTE(kgriffs): https://bugs.python.org/issue28969
-_PYVER_TRIPLET = sys.version_info[:3]
-if _PYVER_TRIPLET >= (3, 5, 4) and _PYVER_TRIPLET != (3, 6, 0):
+if PYTHON_VERSION >= (3, 5, 4) and PYTHON_VERSION != (3, 6, 0):
     _lru_cache_safe = functools.lru_cache  # type: ignore
 else:
     _lru_cache_safe = _lru_cache_nop  # pragma: nocover
@@ -301,7 +300,8 @@ def get_argnames(func):
     args = [
         param.name
         for param in sig.parameters.values()
-        if param.kind not in (inspect.Parameter.VAR_POSITIONAL, inspect.Parameter.VAR_KEYWORD)
+        if param.kind
+        not in (inspect.Parameter.VAR_POSITIONAL, inspect.Parameter.VAR_KEYWORD)
     ]
 
     # NOTE(kgriffs): Depending on the version of Python, 'self' may or may not
@@ -340,8 +340,9 @@ def get_http_status(status_code, default_reason=_DEFAULT_HTTP_REASON):
         if code < 100:
             raise ValueError
     except ValueError:
-        raise ValueError('get_http_status failed: "%s" is not a '
-                         'valid status code', status_code)
+        raise ValueError(
+            'get_http_status failed: "%s" is not a valid status code', status_code
+        )
 
     # lookup the status code
     try:
