@@ -1,6 +1,20 @@
+"""Time and date utilities.
+
+This module provides utility functions and classes for dealing with
+times and dates. These functions are hoisted into the `falcon` module
+for convenience::
+
+    import falcon
+
+    tz = falcon.TimezoneGMT()
+"""
+
 import datetime
 
 
+__all__ = ['TimezoneGMT']
+
+
 class TimezoneGMT(datetime.tzinfo):
     """GMT timezone class implementing the :py:class:`datetime.tzinfo` interface."""
 
@@ -14,7 +28,7 @@ class TimezoneGMT(datetime.tzinfo):
 
         Returns:
             datetime.timedelta: GMT offset, which is equivalent to UTC and
-                so is aways 0.
+            so is aways 0.
         """
 
         return self.GMT_ZERO
