@@ -6,6 +6,8 @@ import pytest
 import falcon
 from falcon import testing
 
+from _util import create_app, create_resp  # NOQA
+
 
 # --------------------------------------------------------------------
 # Fixtures
@@ -18,10 +20,10 @@ def wrapped_resource_aware():
 
 
 @pytest.fixture
-def client():
-    app = falcon.API()
+def client(asgi):
+    app = create_app(asgi)
 
-    resource = WrappedRespondersResource()
+    resource = WrappedRespondersResourceAsync() if asgi else WrappedRespondersResource()
     app.add_route('/', resource)
 
     return testing.TestClient(app)
@@ -34,36 +36,40 @@ def client():
 
 def validate_output(req, resp, resource):
     assert resource
-    raise falcon.HTTPError(falcon.HTTP_723, 'Tricky')
+    raise falcon.HTTPError(falcon.HTTP_723, title='Tricky')
 
 
 def serialize_body(req, resp, resource):
     assert resource
 
-    body = resp.body
+    body = resp.text
     if body is not None:
-        resp.body = json.dumps(body)
+        resp.text = json.dumps(body)
     else:
-        resp.body = 'Nothing to see here. Move along.'
+        resp.text = 'Nothing to see here. Move along.'
+
+
+async def serialize_body_async(*args):
+    return serialize_body(*args)
 
 
 def fluffiness(req, resp, resource, animal=''):
     assert resource
 
-    resp.body = 'fluffy'
+    resp.text = 'fluffy'
     if animal:
         resp.set_header('X-Animal', animal)
 
 
-class ResourceAwareFluffiness(object):
+class ResourceAwareFluffiness:
     def __call__(self, req, resp, resource):
         fluffiness(req, resp, resource)
 
 
 def cuteness(req, resp, resource, check, postfix=' and cute'):
     assert resource
-    if resp.body == check:
-        resp.body += postfix
+    if resp.text == check:
+        resp.text += postfix
 
 
 def resource_aware_cuteness(req, resp, resource):
@@ -71,13 +77,13 @@ def resource_aware_cuteness(req, resp, resource):
     cuteness(req, resp, resource, 'fluffy')
 
 
-class Smartness(object):
+class Smartness:
     def __call__(self, req, resp, resource):
         assert resource
-        if resp.body:
-            resp.body += ' and smart'
+        if resp.text:
+            resp.text += ' and smart'
         else:
-            resp.body = 'smart'
+            resp.text = 'smart'
 
 
 # NOTE(kgriffs): Use partial methods for these next two in order
@@ -87,12 +93,10 @@ def things_in_the_head(header, value, req, resp, resource):
     resp.set_header(header, value)
 
 
-bunnies_in_the_head = functools.partial(things_in_the_head,
-                                        'X-Bunnies', 'fluffy')
+bunnies_in_the_head = functools.partial(things_in_the_head, 'X-Bunnies', 'fluffy')
 
 
-cuteness_in_the_head = functools.partial(things_in_the_head,
-                                         'X-Cuteness', 'cute')
+cuteness_in_the_head = functools.partial(things_in_the_head, 'X-Cuteness', 'cute')
 
 
 def fluffiness_in_the_head(req, resp, resource, value='fluffy'):
@@ -104,8 +108,7 @@ def fluffiness_in_the_head(req, resp, resource, value='fluffy'):
 # --------------------------------------------------------------------
 
 
-class WrappedRespondersResource(object):
-
+class WrappedRespondersResource:
     @falcon.after(serialize_body)
     @falcon.after(validate_output)
     def on_get(self, req, resp):
@@ -116,16 +119,34 @@ class WrappedRespondersResource(object):
     def on_put(self, req, resp):
         self.req = req
         self.resp = resp
-        resp.body = {'animal': 'falcon'}
+        resp.text = {'animal': 'falcon'}
 
     @falcon.after(Smartness())
     def on_post(self, req, resp):
         pass
 
 
+class WrappedRespondersResourceAsync:
+    @falcon.after(serialize_body_async)
+    @falcon.after(validate_output, is_async=False)
+    async def on_get(self, req, resp):
+        self.req = req
+        self.resp = resp
+
+    @falcon.after(serialize_body_async, is_async=True)
+    async def on_put(self, req, resp):
+        self.req = req
+        self.resp = resp
+        resp.text = {'animal': 'falcon'}
+
+    @falcon.after(Smartness())
+    async def on_post(self, req, resp):
+        pass
+
+
 @falcon.after(cuteness, 'fluffy', postfix=' and innocent')
 @falcon.after(fluffiness, 'kitten')
-class WrappedClassResource(object):
+class WrappedClassResource:
 
     # Test that the decorator skips non-callables
     on_post = False
@@ -151,32 +172,33 @@ class WrappedClassResourceChild(WrappedClassResource):
         super(WrappedClassResourceChild, self).on_head(req, resp)
 
 
-class ClassResourceWithURIFields(object):
-
+class ClassResourceWithURIFields:
     @falcon.after(fluffiness_in_the_head, 'fluffy')
     def on_get(self, req, resp, field1, field2):
         self.fields = (field1, field2)
 
 
-class ClassResourceWithURIFieldsChild(ClassResourceWithURIFields):
+class ClassResourceWithURIFieldsAsync:
+    @falcon.after(fluffiness_in_the_head, 'fluffy')
+    async def on_get(self, req, resp, field1, field2):
+        self.fields = (field1, field2)
 
+
+class ClassResourceWithURIFieldsChild(ClassResourceWithURIFields):
     def on_get(self, req, resp, field1, field2):
         # Test passing mixed args and kwargs
         super(ClassResourceWithURIFieldsChild, self).on_get(
-            req,
-            resp,
-            field1,
-            field2=field2
+            req, resp, field1, field2=field2
         )
 
 
 # NOTE(swistakm): we use both type of hooks (class and method)
 # at once for the sake of simplicity
 @falcon.after(resource_aware_cuteness)
-class ClassResourceWithAwareHooks(object):
+class ClassResourceWithAwareHooks:
 
     # Test that the decorator skips non-callables
-    on_post = False
+    on_delete = False
 
     hook_as_class = ResourceAwareFluffiness()
 
@@ -227,11 +249,7 @@ def test_hook_as_callable_class(client):
 
 
 @pytest.mark.parametrize(
-    'resource',
-    [
-        ClassResourceWithURIFields(),
-        ClassResourceWithURIFieldsChild()
-    ]
+    'resource', [ClassResourceWithURIFields(), ClassResourceWithURIFieldsChild()]
 )
 def test_resource_with_uri_fields(client, resource):
     client.app.add_route('/{field1}/{field2}', resource)
@@ -244,12 +262,32 @@ def test_resource_with_uri_fields(client, resource):
     assert resource.fields == ('82074', '58927')
 
 
+def test_resource_with_uri_fields_async():
+    app = create_app(asgi=True)
+
+    resource = ClassResourceWithURIFieldsAsync()
+    app.add_route('/{field1}/{field2}', resource)
+
+    result = testing.simulate_get(app, '/a/b')
+
+    assert result.status_code == 200
+    assert result.headers['X-Fluffiness'] == 'fluffy'
+    assert resource.fields == ('a', 'b')
+
+    async def test_direct():
+        resource = ClassResourceWithURIFieldsAsync()
+
+        req = testing.create_asgi_req()
+        resp = create_resp(True)
+
+        await resource.on_get(req, resp, '1', '2')
+        assert resource.fields == ('1', '2')
+
+    falcon.async_to_sync(test_direct)
+
+
 @pytest.mark.parametrize(
-    'resource',
-    [
-        WrappedClassResource(),
-        WrappedClassResourceChild()
-    ]
+    'resource', [WrappedClassResource(), WrappedClassResourceChild()]
 )
 def test_wrapped_resource(client, resource):
     client.app.add_route('/wrapped', resource)
@@ -292,7 +330,7 @@ def test_wrapped_resource_with_hooks_aware_of_resource(client, wrapped_resource_
     ):
         result = test(path='/wrapped_aware')
         assert result.status_code == 200
-        assert wrapped_resource_aware.resp.body == expected
+        assert wrapped_resource_aware.resp.text == expected
 
     result = client.simulate_patch('/wrapped_aware')
     assert result.status_code == 405
@@ -303,7 +341,7 @@ def test_wrapped_resource_with_hooks_aware_of_resource(client, wrapped_resource_
     assert not result.text
 
 
-class ResourceAwareGameHook(object):
+class ResourceAwareGameHook:
 
     VALUES = ('rock', 'scissors', 'paper')
 
@@ -328,8 +366,7 @@ _game_hook = ResourceAwareGameHook()
 
 @falcon.after(_game_hook)
 @falcon.after(_game_hook)
-class HandGame(object):
-
+class HandGame:
     def __init__(self):
         self.seed = None
 
@@ -356,7 +393,7 @@ class HandGame(object):
 
 @pytest.fixture
 def game_client():
-    app = falcon.API()
+    app = falcon.App()
     resource = HandGame()
 
     app.add_route('/seed', resource)
@@ -367,12 +404,15 @@ def game_client():
     return testing.TestClient(app)
 
 
-@pytest.mark.parametrize('seed,uri,expected', [
-    ('paper', '/once', 'paper, rock, scissors'),
-    ('scissors', '/twice', 'scissors, paper, rock, scissors'),
-    ('rock', '/thrice', 'rock, scissors, paper, rock, scissors'),
-    ('paper', '/thrice', 'paper, rock, scissors, paper, rock'),
-])
+@pytest.mark.parametrize(
+    'seed,uri,expected',
+    [
+        ('paper', '/once', 'paper, rock, scissors'),
+        ('scissors', '/twice', 'scissors, paper, rock, scissors'),
+        ('rock', '/thrice', 'rock, scissors, paper, rock, scissors'),
+        ('paper', '/thrice', 'paper, rock, scissors, paper, rock'),
+    ],
+)
 def test_after_hooks_on_suffixed_resource(game_client, seed, uri, expected):
     game_client.simulate_put('/seed', json=seed)
 
