@@ -7,11 +7,14 @@ import pytest
 import falcon
 import falcon.testing as testing
 
+from _util import create_app, create_resp, disable_asgi_non_coroutine_wrapping  # NOQA
+
 
 def validate(req, resp, resource, params):
     assert resource
-    raise falcon.HTTPBadRequest('Invalid thing', 'Your thing was not '
-                                'formatted correctly.')
+    raise falcon.HTTPBadRequest(
+        title='Invalid thing', description='Your thing was not formatted correctly.'
+    )
 
 
 def validate_param(req, resp, resource, params, param_name, maxval=100):
@@ -20,10 +23,14 @@ def validate_param(req, resp, resource, params, param_name, maxval=100):
     limit = req.get_param_as_int(param_name)
     if limit and int(limit) > maxval:
         msg = '{0} must be <= {1}'.format(param_name, maxval)
-        raise falcon.HTTPBadRequest('Out of Range', msg)
+        raise falcon.HTTPBadRequest(title='Out of Range', description=msg)
 
 
-class ResourceAwareValidateParam(object):
+async def validate_param_async(*args, **kwargs):
+    validate_param(*args, **kwargs)
+
+
+class ResourceAwareValidateParam:
     def __call__(self, req, resp, resource, params):
         assert resource
         validate_param(req, resp, resource, params, 'limit')
@@ -41,11 +48,20 @@ def validate_field(req, resp, resource, params, field_name='test'):
 def parse_body(req, resp, resource, params):
     assert resource
 
-    length = req.content_length or 0
-    if length != 0:
+    length = req.content_length
+    if length:
         params['doc'] = json.load(io.TextIOWrapper(req.bounded_stream, 'utf-8'))
 
 
+async def parse_body_async(req, resp, resource, params):
+    assert resource
+
+    length = req.content_length
+    if length:
+        data = await req.bounded_stream.read()
+        params['doc'] = json.loads(data.decode('utf-8'))
+
+
 def bunnies(req, resp, resource, params):
     assert resource
     params['bunnies'] = 'fuzzy'
@@ -60,7 +76,7 @@ def frogs(req, resp, resource, params):
     params['frogs'] = 'not fluffy'
 
 
-class Fish(object):
+class Fish:
     def __call__(self, req, resp, resource, params):
         assert resource
         params['fish'] = 'slippery'
@@ -76,27 +92,16 @@ def things_in_the_head(header, value, req, resp, resource, params):
     resp.set_header(header, value)
 
 
-bunnies_in_the_head = functools.partial(
-    things_in_the_head,
-    'X-Bunnies',
-    'fluffy'
-)
+bunnies_in_the_head = functools.partial(things_in_the_head, 'X-Bunnies', 'fluffy')
 
-frogs_in_the_head = functools.partial(
-    things_in_the_head,
-    'X-Frogs',
-    'not fluffy'
-)
+frogs_in_the_head = functools.partial(things_in_the_head, 'X-Frogs', 'not fluffy')
 
 
-class WrappedRespondersResource(object):
-
+class WrappedRespondersResource:
     @falcon.before(validate_param, 'limit', 100)
-    @falcon.before(parse_body)
-    def on_get(self, req, resp, doc):
+    def on_get(self, req, resp):
         self.req = req
         self.resp = resp
-        self.doc = doc
 
     @falcon.before(validate)
     def on_put(self, req, resp):
@@ -105,7 +110,6 @@ class WrappedRespondersResource(object):
 
 
 class WrappedRespondersResourceChild(WrappedRespondersResource):
-
     @falcon.before(validate_param, 'x', maxval=1000)
     def on_get(self, req, resp):
         pass
@@ -115,13 +119,22 @@ class WrappedRespondersResourceChild(WrappedRespondersResource):
         super(WrappedRespondersResourceChild, self).on_put(req, resp)
 
 
+class WrappedRespondersBodyParserResource:
+    @falcon.before(validate_param, 'limit', 100)
+    @falcon.before(parse_body)
+    def on_get(self, req, resp, doc=None):
+        self.req = req
+        self.resp = resp
+        self.doc = doc
+
+
 @falcon.before(bunnies)
-class WrappedClassResource(object):
+class WrappedClassResource:
 
     _some_fish = Fish()
 
     # Test non-callable should be skipped by decorator
-    on_patch = {}
+    on_patch = {}  # type: ignore
 
     @falcon.before(validate_param, 'limit')
     def on_get(self, req, resp, bunnies):
@@ -150,7 +163,7 @@ class WrappedClassResource(object):
 # NOTE(swistakm): we use both type of hooks (class and method)
 # at once for the sake of simplicity
 @falcon.before(bunnies)
-class ClassResourceWithAwareHooks(object):
+class ClassResourceWithAwareHooks:
     hook_as_class = ResourceAwareValidateParam()
 
     @falcon.before(validate_param, 'limit', 10)
@@ -175,22 +188,19 @@ class ClassResourceWithAwareHooks(object):
         self.bunnies = bunnies
 
 
-class TestFieldResource(object):
-
+class TestFieldResource:
     @falcon.before(validate_field, field_name='id')
     def on_get(self, req, resp, id):
         self.id = id
 
 
 class TestFieldResourceChild(TestFieldResource):
-
     def on_get(self, req, resp, id):
         # Test passing a single extra arg
         super(TestFieldResourceChild, self).on_get(req, resp, id)
 
 
 class TestFieldResourceChildToo(TestFieldResource):
-
     def on_get(self, req, resp, id):
         # Test passing a single kwarg, but no extra args
         super(TestFieldResourceChildToo, self).on_get(req, resp, id=id)
@@ -201,8 +211,7 @@ class TestFieldResourceChildToo(TestFieldResource):
 @falcon.before(Fish())
 @falcon.before(bunnies_in_the_head)
 @falcon.before(frogs_in_the_head)
-class ZooResource(object):
-
+class ZooResource:
     def on_get(self, req, resp, bunnies, frogs, fish):
         self.bunnies = bunnies
         self.frogs = frogs
@@ -210,16 +219,14 @@ class ZooResource(object):
 
 
 class ZooResourceChild(ZooResource):
-
     def on_get(self, req, resp):
         super(ZooResourceChild, self).on_get(
             req,
             resp,
-
             # Test passing a mixture of args and kwargs
             'fluffy',
             'not fluffy',
-            fish='slippery'
+            fish='slippery',
         )
 
 
@@ -239,8 +246,8 @@ def resource():
 
 
 @pytest.fixture
-def client(resource):
-    app = falcon.API()
+def client(asgi, request, resource):
+    app = create_app(asgi)
     app.add_route('/', resource)
     return testing.TestClient(app)
 
@@ -290,7 +297,7 @@ def test_param_validator(client):
         TestFieldResource(),
         TestFieldResourceChild(),
         TestFieldResourceChildToo(),
-    ]
+    ],
 )
 def test_field_validator(client, resource):
     client.app.add_route('/queue/{id}/messages', resource)
@@ -302,9 +309,68 @@ def test_field_validator(client, resource):
     assert result.status_code == 400
 
 
-def test_parser(client, resource):
-    client.simulate_get('/', body=json.dumps({'animal': 'falcon'}))
-    assert resource.doc == {'animal': 'falcon'}
+@pytest.mark.parametrize(
+    'body,doc',
+    [
+        (json.dumps({'animal': 'falcon'}), {'animal': 'falcon'}),
+        ('{}', {}),
+        ('', None),
+        (None, None),
+    ],
+)
+def test_parser_sync(body, doc):
+    app = falcon.App()
+
+    resource = WrappedRespondersBodyParserResource()
+    app.add_route('/', resource)
+
+    testing.simulate_get(app, '/', body=body)
+    assert resource.doc == doc
+
+
+@pytest.mark.parametrize(
+    'body,doc',
+    [
+        (json.dumps({'animal': 'falcon'}), {'animal': 'falcon'}),
+        ('{}', {}),
+        ('', None),
+        (None, None),
+    ],
+)
+def test_parser_async(body, doc):
+    with disable_asgi_non_coroutine_wrapping():
+
+        class WrappedRespondersBodyParserAsyncResource:
+            @falcon.before(validate_param_async, 'limit', 100, is_async=True)
+            @falcon.before(parse_body_async)
+            async def on_get(self, req, resp, doc=None):
+                self.doc = doc
+
+            @falcon.before(parse_body_async, is_async=False)
+            async def on_put(self, req, resp, doc=None):
+                self.doc = doc
+
+    app = create_app(asgi=True)
+
+    resource = WrappedRespondersBodyParserAsyncResource()
+    app.add_route('/', resource)
+
+    testing.simulate_get(app, '/', body=body)
+    assert resource.doc == doc
+
+    testing.simulate_put(app, '/', body=body)
+    assert resource.doc == doc
+
+    async def test_direct():
+        resource = WrappedRespondersBodyParserAsyncResource()
+
+        req = testing.create_asgi_req()
+        resp = create_resp(True)
+
+        await resource.on_get(req, resp, doc)
+        assert resource.doc == doc
+
+    falcon.async_to_sync(test_direct)
 
 
 def test_wrapped_resource(client, wrapped_resource):
@@ -358,8 +424,7 @@ def header_hook(req, resp, resource, params):
 
 
 @falcon.before(header_hook)
-class PiggybackingCollection(object):
-
+class PiggybackingCollection:
     def __init__(self):
         self._items = {}
         self._sequence = 0
@@ -375,7 +440,7 @@ class PiggybackingCollection(object):
     @falcon.before(header_hook)
     def on_delete_collection(self, req, resp, fish):
         if fish != 'wet':
-            raise falcon.HTTPUnavailableForLegalReasons('fish must be wet')
+            raise falcon.HTTPUnavailableForLegalReasons(title='fish must be wet')
         self._items = {}
         resp.status = falcon.HTTP_NO_CONTENT
 
@@ -385,8 +450,7 @@ class PiggybackingCollection(object):
         resp.media = self._items[itemid]
 
     def on_get_collection(self, req, resp):
-        resp.media = sorted(self._items.values(),
-                            key=lambda item: item['itemid'])
+        resp.media = sorted(self._items.values(), key=lambda item: item['itemid'])
 
     def on_head_(self):
         return 'I shall not be decorated.'
@@ -402,11 +466,24 @@ class PiggybackingCollection(object):
         resp.status = falcon.HTTP_CREATED
 
 
-@pytest.fixture
-def app_client():
-    items = PiggybackingCollection()
+class PiggybackingCollectionAsync(PiggybackingCollection):
+    @falcon.before(header_hook)
+    async def on_post_collection(self, req, resp):
+        self._sequence += 1
+        itemid = self._sequence
 
-    app = falcon.API()
+        doc = await req.get_media()
+
+        self._items[itemid] = dict(doc, itemid=itemid)
+        resp.location = '/items/{}'.format(itemid)
+        resp.status = falcon.HTTP_CREATED
+
+
+@pytest.fixture(params=[True, False])
+def app_client(request):
+    items = PiggybackingCollectionAsync() if request.param else PiggybackingCollection()
+
+    app = create_app(asgi=request.param)
     app.add_route('/items', items, suffix='collection')
     app.add_route('/items/{itemid:int}', items)
 
@@ -441,7 +518,7 @@ def test_piggybacking_resource_post_and_delete(app_client):
 
         assert len(app_client.simulate_get('/items').json) == number
 
-    resp = app_client.simulate_delete('/items/7'.format(number))
+    resp = app_client.simulate_delete('/items/{}'.format(number))
     assert resp.status_code == 204
     assert resp.headers['X-Fish-Trait'] == 'wet'
     assert resp.headers['X-Hook-Applied'] == '1'
