@@ -1,4 +1,5 @@
 from datetime import datetime, timedelta, tzinfo
+from http import cookies as http_cookies
 import re
 
 import pytest
@@ -6,14 +7,14 @@ import pytest
 import falcon
 import falcon.testing as testing
 from falcon.util import http_date_to_dt, TimezoneGMT
-from falcon.util.compat import http_cookies
+
+from _util import create_app  # NOQA
 
 
-UNICODE_TEST_STRING = u'Unicode_\xc3\xa6\xc3\xb8'
+UNICODE_TEST_STRING = 'Unicode_\xc3\xa6\xc3\xb8'
 
 
 class TimezoneGMTPlus1(tzinfo):
-
     def utcoffset(self, dt):
         return timedelta(hours=1)
 
@@ -28,7 +29,6 @@ GMT_PLUS_ONE = TimezoneGMTPlus1()
 
 
 class CookieResource:
-
     def on_get(self, req, resp):
         resp.set_cookie('foo', 'bar', domain='example.com', path='/')
 
@@ -50,19 +50,40 @@ class CookieResource:
 
 
 class CookieResourceMaxAgeFloatString:
-
     def on_get(self, req, resp):
-        resp.set_cookie(
-            'foofloat', 'bar', max_age=15.3, secure=False, http_only=False)
-        resp.set_cookie(
-            'foostring', 'bar', max_age='15', secure=False, http_only=False)
+        resp.set_cookie('foofloat', 'bar', max_age=15.3, secure=False, http_only=False)
+        resp.set_cookie('foostring', 'bar', max_age='15', secure=False, http_only=False)
 
 
-@pytest.fixture()
-def client():
-    app = falcon.API()
+class CookieResourceSameSite:
+    def on_get(self, req, resp):
+        resp.set_cookie('foo', 'bar', same_site='Lax')
+
+    def on_post(self, req, resp):
+        resp.set_cookie('bar', 'foo', same_site='STRICT')
+
+    def on_put(self, req, resp):
+        resp.set_cookie('baz', 'foo', same_site='none')
+
+    def on_delete(self, req, resp):
+        resp.set_cookie('baz', 'foo', same_site='')
+
+
+class CookieUnset:
+    def on_get(self, req, resp):
+        resp.unset_cookie('foo')
+        resp.unset_cookie('bar', path='/bar')
+        resp.unset_cookie('baz', domain='www.example.com')
+        resp.unset_cookie('foobar', path='/foo', domain='www.example.com')
+
+
+@pytest.fixture
+def client(asgi):
+    app = create_app(asgi)
     app.add_route('/', CookieResource())
     app.add_route('/test-convert', CookieResourceMaxAgeFloatString())
+    app.add_route('/same-site', CookieResourceSameSite())
+    app.add_route('/unset-cookie', CookieUnset())
 
     return testing.TestClient(app)
 
@@ -76,6 +97,7 @@ def test_response_base_case(client):
     result = client.simulate_get('/')
 
     cookie = result.cookies['foo']
+
     assert cookie.name == 'foo'
     assert cookie.value == 'bar'
     assert cookie.domain == 'example.com'
@@ -130,6 +152,7 @@ def test_response_complex_case(client):
     cookie = result.cookies['bad']
     assert cookie.value == ''  # An unset cookie has an empty value
     assert cookie.domain is None
+    assert cookie.same_site == 'Lax'
 
     assert cookie.expires < datetime.utcnow()
 
@@ -144,6 +167,24 @@ def test_response_complex_case(client):
     assert cookie.secure
 
 
+def test_unset_cookies(client):
+    result = client.simulate_get('/unset-cookie')
+
+    assert len(result.cookies) == 4
+
+    def test(cookie, path, domain):
+        assert cookie.value == ''  # An unset cookie has an empty value
+        assert cookie.domain == domain
+        assert cookie.path == path
+        assert cookie.same_site == 'Lax'
+        assert cookie.expires < datetime.utcnow()
+
+    test(result.cookies['foo'], path=None, domain=None)
+    test(result.cookies['bar'], path='/bar', domain=None)
+    test(result.cookies['baz'], path=None, domain='www.example.com')
+    test(result.cookies['foobar'], path='/foo', domain='www.example.com')
+
+
 def test_cookie_expires_naive(client):
     result = client.simulate_post('/')
 
@@ -212,7 +253,7 @@ def test_response_unset_cookie(client):
     len(morsels) == 1
 
     bad_cookie = morsels[0]
-    bad_cookie['expires'] == -1
+    assert bad_cookie['expires'] == -1
 
     output = bad_cookie.OutputString()
     assert 'bad=;' in output or 'bad="";' in output
@@ -246,7 +287,7 @@ def test_request_cookie_parsing():
             tz3=Europe/Madrid ;_ga3= GA3.2.332347814.1422308165;
             _gat=1;
             _octo=GH1.1.201722077.1422308165
-            """
+            """,
         ),
     ]
 
@@ -283,10 +324,7 @@ def test_invalid_cookies_are_ignored():
 
     for c in vals:
         headers = [
-            (
-                'Cookie',
-                'good_cookie=foo;bad' + c + 'cookie=bar'
-            ),
+            ('Cookie', 'good_cookie=foo;bad' + c + 'cookie=bar'),
         ]
 
         environ = testing.create_environ(headers=headers)
@@ -298,10 +336,7 @@ def test_invalid_cookies_are_ignored():
 
 def test_duplicate_cookie():
     headers = [
-        (
-            'Cookie',
-            'x=1;bad{cookie=bar; x=2;x=3 ; x=4;'
-        ),
+        ('Cookie', 'x=1;bad{cookie=bar; x=2;x=3 ; x=4;'),
     ]
 
     environ = testing.create_environ(headers=headers)
@@ -330,18 +365,13 @@ def test_unicode_inside_ascii_range():
 
     # should be ok
     resp.set_cookie('non_unicode_ascii_name_1', 'ascii_value')
-    resp.set_cookie(u'unicode_ascii_name_1', 'ascii_value')
-    resp.set_cookie('non_unicode_ascii_name_2', u'unicode_ascii_value')
-    resp.set_cookie(u'unicode_ascii_name_2', u'unicode_ascii_value')
+    resp.set_cookie('unicode_ascii_name_1', 'ascii_value')
+    resp.set_cookie('non_unicode_ascii_name_2', 'unicode_ascii_value')
+    resp.set_cookie('unicode_ascii_name_2', 'unicode_ascii_value')
 
 
 @pytest.mark.parametrize(
-    'name',
-    (
-        UNICODE_TEST_STRING,
-        UNICODE_TEST_STRING.encode('utf-8'),
-        42
-    )
+    'name', (UNICODE_TEST_STRING, UNICODE_TEST_STRING.encode('utf-8'), 42)
 )
 def test_non_ascii_name(name):
     resp = falcon.Response()
@@ -350,12 +380,7 @@ def test_non_ascii_name(name):
 
 
 @pytest.mark.parametrize(
-    'value',
-    (
-        UNICODE_TEST_STRING,
-        UNICODE_TEST_STRING.encode('utf-8'),
-        42
-    )
+    'value', (UNICODE_TEST_STRING, UNICODE_TEST_STRING.encode('utf-8'), 42)
 )
 def test_non_ascii_value(value):
     resp = falcon.Response()
@@ -370,3 +395,52 @@ def test_non_ascii_value(value):
         assert not isinstance(e, UnicodeEncodeError)
     else:
         pytest.fail('set_bad_cookie_value did not fail as expected')
+
+
+def test_lax_same_site_value(client):
+    result = client.simulate_get('/same-site')
+    cookie = result.cookies['foo']
+
+    assert cookie.same_site == 'Lax'
+
+
+def test_strict_same_site_value(client):
+    result = client.simulate_post('/same-site')
+    cookie = result.cookies['bar']
+
+    assert cookie.same_site == 'Strict'
+
+
+def test_none_same_site_value(client):
+    result = client.simulate_put('/same-site')
+    cookie = result.cookies['baz']
+
+    assert cookie.same_site == 'None'
+
+
+def test_same_site_empty_string(client):
+    result = client.simulate_delete('/same-site')
+    cookie = result.cookies['baz']
+
+    assert cookie.same_site is None
+
+
+@pytest.mark.parametrize(
+    'same_site', ['laX', 'lax', 'STRICT', 'strict', 'None', 'none']
+)
+def test_same_site_value_case_insensitive(same_site):
+    resp = falcon.Response()
+    resp.set_cookie('foo', 'bar', same_site=same_site)
+
+    # NOTE(kgriffs): Verify directly, unit-test style, since we
+    #   already tested end-to-end above.
+    morsel = resp._cookies['foo']
+    assert morsel['samesite'].lower() == same_site.lower()
+
+
+@pytest.mark.parametrize('same_site', ['bogus', 'laxx', 'stric'])
+def test_invalid_same_site_value(same_site):
+    resp = falcon.Response()
+
+    with pytest.raises(ValueError):
+        resp.set_cookie('foo', 'bar', same_site=same_site)
