@@ -3,29 +3,40 @@ from functools import wraps
 import pytest
 
 import falcon
+import falcon.constants
 import falcon.testing as testing
 
-HTTP_METHODS = (
+from _util import create_app  # NOQA
+
+# RFC 7231, 5789 methods
+HTTP_METHODS = [
     'CONNECT',
     'DELETE',
     'GET',
     'HEAD',
     'OPTIONS',
+    'PATCH',
     'POST',
     'PUT',
     'TRACE',
-    'PATCH'
-)
+]
 
-
-WEBDAV_METHODS = (
+# RFC 2518 and 4918 methods
+WEBDAV_METHODS = [
     'CHECKIN',
     'CHECKOUT',
+    'COPY',
+    'LOCK',
+    'MKCOL',
+    'MOVE',
+    'PROPFIND',
+    'PROPPATCH',
     'REPORT',
     'UNCHECKIN',
+    'UNLOCK',
     'UPDATE',
     'VERSION-CONTROL',
-)
+]
 
 
 @pytest.fixture
@@ -49,8 +60,8 @@ def resource_get_with_faulty_put():
 
 
 @pytest.fixture
-def client():
-    app = falcon.API()
+def client(asgi):
+    app = create_app(asgi)
 
     app.add_route('/stonewall', Stonewall())
 
@@ -66,7 +77,7 @@ def client():
     return testing.TestClient(app)
 
 
-class ThingsResource(object):
+class ThingsResource:
     def __init__(self):
         self.called = False
 
@@ -99,8 +110,11 @@ class ThingsResource(object):
         self.req, self.resp = req, resp
         resp.status = falcon.HTTP_204
 
+    def on_websocket(self, req, resp, id, sid):
+        self.called = True
 
-class Stonewall(object):
+
+class Stonewall:
     pass
 
 
@@ -122,7 +136,7 @@ def selfless_decorator(func):
     return faulty
 
 
-class MiscResource(object):
+class MiscResource:
     def __init__(self):
         self.called = False
 
@@ -152,7 +166,7 @@ class MiscResource(object):
         resp.set_header('allow', 'GET')
 
 
-class GetWithFaultyPutResource(object):
+class GetWithFaultyPutResource:
     def __init__(self):
         self.called = False
 
@@ -164,15 +178,13 @@ class GetWithFaultyPutResource(object):
         raise TypeError()
 
 
-class FaultyDecoratedResource(object):
-
+class FaultyDecoratedResource:
     @selfless_decorator
     def on_get(self, req, resp):
         pass
 
 
-class TestHttpMethodRouting(object):
-
+class TestHttpMethodRouting:
     def test_get(self, client, resource_things):
         client.app.add_route('/things', resource_things)
         client.app.add_route('/things/{id}/stuff/{sid}', resource_things)
@@ -197,7 +209,9 @@ class TestHttpMethodRouting(object):
     def test_report(self, client, resource_things):
         client.app.add_route('/things', resource_things)
         client.app.add_route('/things/{id}/stuff/{sid}', resource_things)
-        response = client.simulate_request(path='/things/42/stuff/1337', method='REPORT')
+        response = client.simulate_request(
+            path='/things/42/stuff/1337', method='REPORT'
+        )
         assert response.status == falcon.HTTP_204
         assert resource_things.called
 
@@ -223,7 +237,9 @@ class TestHttpMethodRouting(object):
                 continue
 
             resource_things.called = False
-            response = client.simulate_request(path='/things/84/stuff/65', method=method)
+            response = client.simulate_request(
+                path='/things/84/stuff/65', method=method
+            )
 
             assert not resource_things.called
             assert response.status == falcon.HTTP_405
@@ -265,9 +281,14 @@ class TestHttpMethodRouting(object):
         headers = response.headers
         assert headers['allow'] == 'GET'
 
-    def test_bogus_method(self, client, resource_things):
-        client.app.add_route('/things', resource_things)
+    @pytest.mark.parametrize(
+        'method', falcon.constants._META_METHODS + ['SETECASTRONOMY']
+    )
+    @pytest.mark.filterwarnings('ignore:Unknown REQUEST_METHOD')
+    def test_meta_and_others_disallowed(self, client, resource_things, method):
         client.app.add_route('/things/{id}/stuff/{sid}', resource_things)
-        response = client.simulate_request(path='/things', method='SETECASTRONOMY')
-        assert not resource_things.called
+        response = client.simulate_request(
+            path='/things/42/stuff/1337', method='WEBSOCKET'
+        )
         assert response.status == falcon.HTTP_400
+        assert not resource_things.called
