@@ -31,7 +31,8 @@ EXAMPLE1 = (
     b'Content-Disposition: form-data; name="file1"; filename="test.txt"\r\n'
     b'Content-Type: text/plain\r\n\r\n'
     b'Hello, world!\n\r\n'
-    b'--5b11af82ab65407ba8cdccf37d2a9c4f--\r\n')
+    b'--5b11af82ab65407ba8cdccf37d2a9c4f--\r\n'
+)
 
 EXAMPLE2 = (
     b'-----------------------------1574247108204320607285918568\r\n'
@@ -58,9 +59,9 @@ EXAMPLE2_PART_COUNT = 5
 EXAMPLE3 = (
     b'--BOUNDARY\r\n'
     b'Content-Disposition: form-data; name="file"; filename="bytes"\r\n'
-    b'Content-Type: application/x-falcon\r\n\r\n' +
-    b'123456789abcdef\n' * 64 * 1024 * 2 +
-    b'\r\n'
+    b'Content-Type: application/x-falcon\r\n\r\n'
+    + b'123456789abcdef\n' * 64 * 1024 * 2
+    + b'\r\n'
     b'--BOUNDARY\r\n'
     b'Content-Disposition: form-data; name="empty"\r\n'
     b'Content-Type: text/plain\r\n\r\n'
@@ -86,18 +87,14 @@ LOREM_IPSUM = (
 EXAMPLE4 = (
     b'--boundary\r\n'
     b'Content-Disposition: form-data; name="lorem1"; filename="bytes1"\r\n'
-    b'Content-Type: text/plain\r\n\r\n' +
-    LOREM_IPSUM +
-    b'\r\n'
+    b'Content-Type: text/plain\r\n\r\n' + LOREM_IPSUM + b'\r\n'
     b'--boundary\r\n'
     b'Content-Disposition: form-data; name="empty"\r\n'
     b'Content-Type: text/plain\r\n\r\n'
     b'\r\n'
     b'--boundary\r\n'
     b'Content-Disposition: form-data; name="lorem2"; filename="bytes1"\r\n'
-    b'Content-Type: text/plain\r\n\r\n' +
-    LOREM_IPSUM +
-    b'\r\n'
+    b'Content-Type: text/plain\r\n\r\n' + LOREM_IPSUM + b'\r\n'
     b'--boundary--\r\n'
 )
 
@@ -111,8 +108,7 @@ EXAMPLES = {
 
 
 # APPSEC: This SHA256 hash is safe against preimage attacks.
-HASH_BOUNDARY = (
-    'fbeff51e0f5630958701f4941aec5595addcb3ee1b70468c8bd4be920304c184')
+HASH_BOUNDARY = 'fbeff51e0f5630958701f4941aec5595addcb3ee1b70468c8bd4be920304c184'
 
 
 @pytest.mark.parametrize('boundary', list(EXAMPLES))
@@ -120,9 +116,8 @@ def test_parse(boundary):
     handler = media.MultipartFormHandler()
     example = EXAMPLES[boundary]
     form = handler.deserialize(
-        io.BytesIO(example),
-        'multipart/form-data; boundary=' + boundary,
-        len(example))
+        io.BytesIO(example), 'multipart/form-data; boundary=' + boundary, len(example)
+    )
 
     for part in form:
         output = io.BytesIO()
@@ -130,31 +125,36 @@ def test_parse(boundary):
         assert isinstance(output.getvalue(), bytes)
 
 
-@pytest.mark.parametrize('buffer_size,chunk_size', list(itertools.product(
-    (
-        32,
-        64,
-        128,
-        256,
+@pytest.mark.parametrize(
+    'buffer_size,chunk_size',
+    list(
+        itertools.product(
+            (
+                32,
+                64,
+                128,
+                256,
+            ),
+            (
+                7,
+                8,
+                9,
+                10,
+                32,
+                64,
+                128,
+                256,
+            ),
+        )
     ),
-    (
-        7,
-        8,
-        9,
-        10,
-        32,
-        64,
-        128,
-        256,
-    ),
-)))
+)
 def test_parsing_correctness(buffer_size, chunk_size):
     example = EXAMPLES['boundary']
     handler = media.MultipartFormHandler()
-    stream = BufferedReader(io.BytesIO(example).read, len(example),
-                            buffer_size)
+    stream = BufferedReader(io.BytesIO(example).read, len(example), buffer_size)
     form = handler.deserialize(
-        stream, 'multipart/form-data; boundary=boundary', len(example))
+        stream, 'multipart/form-data; boundary=boundary', len(example)
+    )
 
     for part in form:
         if part.name in ('lorem1', 'lorem2'):
@@ -186,8 +186,7 @@ def test_missing_boundary():
 
 def test_empty_input():
     handler = media.MultipartFormHandler()
-    form = handler.deserialize(
-        io.BytesIO(), 'multipart/form-data; boundary=404', 0)
+    form = handler.deserialize(io.BytesIO(), 'multipart/form-data; boundary=404', 0)
     with pytest.raises(falcon.MediaMalformedError):
         for part in form:
             pass
@@ -199,20 +198,23 @@ def test_serialize():
         handler.serialize({'key': 'value'}, 'multipart/form-data')
 
 
-@pytest.mark.parametrize('charset,data', [
-    ('utf-8', b'Impossible byte: \xff'),
-    ('utf-8', b'Overlong... \xfc\x83\xbf\xbf\xbf\xbf ... sequence'),
-    ('ascii', b'\x80\x80\x80'),
-    ('pecyn', b'AAHEHlRoZSBGYWxjb24gV2ViIEZyYW1ld29yaywgMjAxOQ=='),
-])
+@pytest.mark.parametrize(
+    'charset,data',
+    [
+        ('utf-8', b'Impossible byte: \xff'),
+        ('utf-8', b'Overlong... \xfc\x83\xbf\xbf\xbf\xbf ... sequence'),
+        ('ascii', b'\x80\x80\x80'),
+        ('pecyn', b'AAHEHlRoZSBGYWxjb24gV2ViIEZyYW1ld29yaywgMjAxOQ=='),
+    ],
+)
 def test_invalid_text_or_charset(charset, data):
     data = (
         b'--BOUNDARY\r\n'
         b'Content-Disposition: form-data; name="text"\r\n'
-        b'Content-Type: text/plain; ' +
-        'charset={}\r\n\r\n'.format(charset).encode() +
-        data +
-        b'\r\n'
+        b'Content-Type: text/plain; '
+        + 'charset={}\r\n\r\n'.format(charset).encode()
+        + data
+        + b'\r\n'
         b'--BOUNDARY\r\n'
         b'Content-Disposition: form-data; name="empty"\r\n'
         b'Content-Type: text/plain\r\n\r\n'
@@ -223,7 +225,8 @@ def test_invalid_text_or_charset(charset, data):
     handler = media.MultipartFormHandler()
 
     form = handler.deserialize(
-        io.BytesIO(data), 'multipart/form-data; boundary=BOUNDARY', len(data))
+        io.BytesIO(data), 'multipart/form-data; boundary=BOUNDARY', len(data)
+    )
     with pytest.raises(falcon.MediaMalformedError):
         for part in form:
             part.text
@@ -241,7 +244,8 @@ def test_unknown_header():
 
     handler = media.MultipartFormHandler()
     form = handler.deserialize(
-        io.BytesIO(data), 'multipart/form-data; boundary=BOUNDARY', len(data))
+        io.BytesIO(data), 'multipart/form-data; boundary=BOUNDARY', len(data)
+    )
 
     for part in form:
         assert part.data == b''
@@ -260,7 +264,8 @@ def test_from_buffered_stream():
     handler = media.MultipartFormHandler()
     stream = BufferedReader(io.BytesIO(data).read, len(data))
     form = handler.deserialize(
-        stream, 'multipart/form-data; boundary=BOUNDARY', len(data))
+        stream, 'multipart/form-data; boundary=BOUNDARY', len(data)
+    )
 
     for part in form:
         assert part.data == b''
@@ -269,10 +274,8 @@ def test_from_buffered_stream():
 def test_body_part_media():
     handler = media.MultipartFormHandler()
 
-    content_type = ('multipart/form-data; boundary=' +
-                    '5b11af82ab65407ba8cdccf37d2a9c4f')
-    form = handler.deserialize(
-        io.BytesIO(EXAMPLE1), content_type, len(EXAMPLE1))
+    content_type = 'multipart/form-data; boundary=' + '5b11af82ab65407ba8cdccf37d2a9c4f'
+    form = handler.deserialize(io.BytesIO(EXAMPLE1), content_type, len(EXAMPLE1))
 
     expected = {'debug': True, 'message': 'Hello, world!', 'score': 7}
 
@@ -284,10 +287,8 @@ def test_body_part_media():
 def test_body_part_properties():
     handler = media.MultipartFormHandler()
 
-    content_type = ('multipart/form-data; boundary=' +
-                    '5b11af82ab65407ba8cdccf37d2a9c4f')
-    form = handler.deserialize(
-        io.BytesIO(EXAMPLE1), content_type, len(EXAMPLE1))
+    content_type = 'multipart/form-data; boundary=' + '5b11af82ab65407ba8cdccf37d2a9c4f'
+    form = handler.deserialize(io.BytesIO(EXAMPLE1), content_type, len(EXAMPLE1))
 
     for part in form:
         if part.content_type == 'application/json':
@@ -306,8 +307,7 @@ def test_empty_filename():
     )
 
     handler = media.MultipartFormHandler()
-    content_type = ('multipart/form-data; boundary=' +
-                    'a0d738bcdb30449eb0d13f4b72c2897e')
+    content_type = 'multipart/form-data; boundary=' + 'a0d738bcdb30449eb0d13f4b72c2897e'
     stream = BufferedReader(io.BytesIO(data).read, len(data))
     form = handler.deserialize(stream, content_type, len(data))
 
@@ -325,21 +325,24 @@ async def test_async_unsupported():
     handler = media.MultipartFormHandler()
     with pytest.raises(NotImplementedError):
         await handler.deserialize_async(
-            'Dummy', 'multipart/form-data; boundary=BOUNDARY', None)
+            'Dummy', 'multipart/form-data; boundary=BOUNDARY', None
+        )
 
 
 class MultipartAnalyzer:
     def on_post(self, req, resp):
         values = []
         for part in req.media:
-            values.append({
-                'content_type': part.content_type,
-                'data': part.data.decode(),
-                'filename': part.filename,
-                'name': part.name,
-                'secure_filename': part.secure_filename if part.filename else None,
-                'text': part.text,
-            })
+            values.append(
+                {
+                    'content_type': part.content_type,
+                    'data': part.data.decode(),
+                    'filename': part.filename,
+                    'name': part.name,
+                    'secure_filename': part.secure_filename if part.filename else None,
+                    'text': part.text,
+                }
+            )
 
         resp.media = values
 
@@ -355,11 +358,13 @@ class MultipartAnalyzer:
     def on_post_mirror(self, req, resp):
         parts = []
         for part in req.get_media():
-            parts.append({
-                'content': part.stream.read(),
-                'content_type': part.content_type,
-                'name': part.name,
-            })
+            parts.append(
+                {
+                    'content': part.stream.read(),
+                    'content_type': part.content_type,
+                    'name': part.name,
+                }
+            )
 
         resp.content_type = falcon.MEDIA_MSGPACK
         resp.media = parts
@@ -371,14 +376,16 @@ class AsyncMultipartAnalyzer:
         form = await req.get_media()
         async for part in form:
             # NOTE(vytas): use the async property form to exercise that too.
-            values.append({
-                'content_type': part.content_type,
-                'data': (await part.data).decode(),
-                'filename': part.filename,
-                'name': part.name,
-                'secure_filename': part.secure_filename if part.filename else None,
-                'text': (await part.text),
-            })
+            values.append(
+                {
+                    'content_type': part.content_type,
+                    'data': (await part.data).decode(),
+                    'filename': part.filename,
+                    'name': part.name,
+                    'secure_filename': part.secure_filename if part.filename else None,
+                    'text': (await part.text),
+                }
+            )
 
         resp.media = values
 
@@ -395,11 +402,13 @@ class AsyncMultipartAnalyzer:
     async def on_post_mirror(self, req, resp):
         parts = []
         async for part in await req.get_media():
-            parts.append({
-                'content': await part.stream.read(),
-                'content_type': part.content_type,
-                'name': part.name,
-            })
+            parts.append(
+                {
+                    'content': await part.stream.read(),
+                    'content_type': part.content_type,
+                    'name': part.name,
+                }
+            )
 
         resp.content_type = falcon.MEDIA_MSGPACK
         resp.media = parts
@@ -411,17 +420,21 @@ def custom_client(asgi):
         multipart_handler = media.MultipartFormHandler()
         for key, value in options.items():
             setattr(multipart_handler.parse_options, key, value)
-        req_handlers = media.Handlers({
-            falcon.MEDIA_JSON: media.JSONHandler(),
-            falcon.MEDIA_MULTIPART: multipart_handler,
-        })
+        req_handlers = media.Handlers(
+            {
+                falcon.MEDIA_JSON: media.JSONHandler(),
+                falcon.MEDIA_MULTIPART: multipart_handler,
+            }
+        )
 
         app = create_app(asgi)
         app.req_options.media_handlers = req_handlers
-        app.resp_options.media_handlers = media.Handlers({
-            falcon.MEDIA_JSON: media.JSONHandler(),
-            falcon.MEDIA_MSGPACK: media.MessagePackHandler(),
-        })
+        app.resp_options.media_handlers = media.Handlers(
+            {
+                falcon.MEDIA_JSON: media.JSONHandler(),
+                falcon.MEDIA_MSGPACK: media.MessagePackHandler(),
+            }
+        )
 
         resource = AsyncMultipartAnalyzer() if asgi else MultipartAnalyzer()
         app.add_route('/submit', resource)
@@ -442,10 +455,11 @@ def test_upload_multipart(client):
     resp = client.simulate_post(
         '/submit',
         headers={
-            'Content-Type':
-            'multipart/form-data; boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
+            'Content-Type': 'multipart/form-data; '
+            'boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
         },
-        body=EXAMPLE1)
+        body=EXAMPLE1,
+    )
 
     assert resp.status_code == 200
     assert resp.json == [
@@ -481,10 +495,11 @@ def test_truncated_form(client, truncated_by):
     resp = client.simulate_post(
         '/submit',
         headers={
-            'Content-Type':
-            'multipart/form-data; boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
+            'Content-Type': 'multipart/form-data; '
+            'boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
         },
-        body=EXAMPLE1[:-truncated_by])
+        body=EXAMPLE1[:-truncated_by],
+    )
 
     assert resp.status_code == 400
     assert resp.json == {
@@ -497,10 +512,11 @@ def test_unexected_form_structure(client):
     resp1 = client.simulate_post(
         '/submit',
         headers={
-            'Content-Type':
-            'multipart/form-data; boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
+            'Content-Type': 'multipart/form-data; '
+            'boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
         },
-        body=EXAMPLE1[:-2] + b'--\r\n')
+        body=EXAMPLE1[:-2] + b'--\r\n',
+    )
 
     assert resp1.status_code == 400
     assert resp1.json == {
@@ -511,10 +527,11 @@ def test_unexected_form_structure(client):
     resp2 = client.simulate_post(
         '/submit',
         headers={
-            'Content-Type':
-            'multipart/form-data; boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
+            'Content-Type': 'multipart/form-data; '
+            'boundary=5b11af82ab65407ba8cdccf37d2a9c4f',
         },
-        body=EXAMPLE1[:-4] + b'**\r\n')
+        body=EXAMPLE1[:-4] + b'**\r\n',
+    )
 
     assert resp2.status_code == 400
     assert resp2.json == {
@@ -527,10 +544,10 @@ def test_data_too_large(client):
     resp = client.simulate_post(
         '/submit',
         headers={
-            'Content-Type':
-            'multipart/form-data; boundary=BOUNDARY',
+            'Content-Type': 'multipart/form-data; boundary=BOUNDARY',
         },
-        body=EXAMPLE3)
+        body=EXAMPLE3,
+    )
 
     assert resp.status_code == 400
     assert resp.json == {
@@ -546,10 +563,10 @@ def test_too_many_body_parts(custom_client, max_body_part_count):
     resp = client.simulate_post(
         '/submit',
         headers={
-            'Content-Type':
-            'multipart/form-data; boundary=' + boundary,
+            'Content-Type': 'multipart/form-data; boundary=' + boundary,
         },
-        body=EXAMPLE2)
+        body=EXAMPLE2,
+    )
 
     if 0 < max_body_part_count < EXAMPLE2_PART_COUNT:
         assert resp.status_code == 400
@@ -565,22 +582,25 @@ def test_too_many_body_parts(custom_client, max_body_part_count):
 @pytest.mark.skipif(not msgpack, reason='msgpack not installed')
 def test_random_form(client):
     part_data = [os.urandom(random.randint(0, 2**18)) for _ in range(64)]
-    form_data = b''.join(
-        '--{}\r\n'.format(HASH_BOUNDARY).encode() +
-        'Content-Disposition: form-data; name="p{}"\r\n'.format(i).encode() +
-        b'Content-Type: application/x-falcon-urandom\r\n\r\n' +
-        part_data[i] +
-        b'\r\n'
-        for i in range(64)
-    ) + '--{}--\r\n'.format(HASH_BOUNDARY).encode()
+    form_data = (
+        b''.join(
+            '--{}\r\n'.format(HASH_BOUNDARY).encode()
+            + 'Content-Disposition: form-data; name="p{}"\r\n'.format(i).encode()
+            + b'Content-Type: application/x-falcon-urandom\r\n\r\n'
+            + part_data[i]
+            + b'\r\n'
+            for i in range(64)
+        )
+        + '--{}--\r\n'.format(HASH_BOUNDARY).encode()
+    )
 
     handler = media.MultipartFormHandler()
-    content_type = ('multipart/form-data; boundary=' + HASH_BOUNDARY)
-    form = handler.deserialize(
-        io.BytesIO(form_data), content_type, len(form_data))
+    content_type = 'multipart/form-data; boundary=' + HASH_BOUNDARY
+    form = handler.deserialize(io.BytesIO(form_data), content_type, len(form_data))
 
     resp = client.simulate_post(
-        '/mirror', headers={'Content-Type': content_type}, body=form_data)
+        '/mirror', headers={'Content-Type': content_type}, body=form_data
+    )
     assert resp.status_code == 200
     form = msgpack.unpackb(resp.content, raw=False)
 
@@ -594,10 +614,10 @@ def test_invalid_random_form(client):
     resp = client.simulate_post(
         '/submit',
         headers={
-            'Content-Type':
-            'multipart/form-data; boundary=' + HASH_BOUNDARY,
+            'Content-Type': 'multipart/form-data; boundary=' + HASH_BOUNDARY,
         },
-        body=os.urandom(length))
+        body=os.urandom(length),
+    )
 
     assert resp.status_code == 400
 
@@ -614,8 +634,9 @@ def test_nested_multipart_mixed():
             resp.media = example
 
     parser = media.MultipartFormHandler()
-    parser.parse_options.media_handlers['multipart/mixed'] = (
-        media.MultipartFormHandler())
+    parser.parse_options.media_handlers[
+        'multipart/mixed'
+    ] = media.MultipartFormHandler()
 
     app = falcon.App()
     app.req_options.media_handlers[falcon.MEDIA_MULTIPART] = parser
@@ -669,12 +690,14 @@ def test_content_transfer_encoding_header(client):
     resp = client.simulate_post(
         '/submit',
         headers={'Content-Type': 'multipart/form-data; boundary=BOUNDARY'},
-        body=data)
+        body=data,
+    )
 
     assert resp.status_code == 400
     assert resp.json == {
-        'description': ('the deprecated Content-Transfer-Encoding header '
-                        'field is unsupported'),
+        'description': (
+            'the deprecated Content-Transfer-Encoding header field is unsupported'
+        ),
         'title': 'Malformed multipart/form-data request media',
     }
 
@@ -696,7 +719,8 @@ def test_unsupported_charset(client):
     resp = client.simulate_post(
         '/submit',
         headers={'Content-Type': 'multipart/form-data; boundary=BOUNDARY'},
-        body=data)
+        body=data,
+    )
 
     assert resp.status_code == 400
     assert resp.json == {
@@ -716,24 +740,27 @@ def test_filename_star(client):
         b'A unicode arrow in the filename.\r\n'
         b'--a0d738bcdb30449eb0d13f4b72c2897e--\r\n'
     )
-    content_type = ('multipart/form-data; boundary=' +
-                    'a0d738bcdb30449eb0d13f4b72c2897e')
+    content_type = 'multipart/form-data; boundary=' + 'a0d738bcdb30449eb0d13f4b72c2897e'
 
     resp = client.simulate_post(
-        '/submit', headers={'Content-Type': content_type}, body=data)
+        '/submit', headers={'Content-Type': content_type}, body=data
+    )
     assert resp.status_code == 200
-    assert resp.json == [{
-        'content_type': 'text/plain',
-        'data': 'A unicode arrow in the filename.',
-        'filename': '⬅ Arrow.txt',
-        'name': 'file',
-        'secure_filename': '__Arrow.txt',
-        'text': 'A unicode arrow in the filename.',
-    }]
+    assert resp.json == [
+        {
+            'content_type': 'text/plain',
+            'data': 'A unicode arrow in the filename.',
+            'filename': '⬅ Arrow.txt',
+            'name': 'file',
+            'secure_filename': '__Arrow.txt',
+            'text': 'A unicode arrow in the filename.',
+        }
+    ]
 
     data = data.replace(b'*=utf-8', b'*=esoteric')
     resp = client.simulate_post(
-        '/submit', headers={'Content-Type': content_type}, body=data)
+        '/submit', headers={'Content-Type': content_type}, body=data
+    )
     assert resp.status_code == 400
     assert resp.json == {
         'description': 'invalid text or charset: esoteric',
@@ -754,11 +781,11 @@ def test_headers_edge_cases(custom_client, max_headers_size):
         b'No, it is not an ODT document...\r\n'
         b'--a0d738bcdb30449eb0d13f4b72c2897e--\r\n'
     )
-    content_type = ('multipart/form-data; boundary=' +
-                    'a0d738bcdb30449eb0d13f4b72c2897e')
+    content_type = 'multipart/form-data; boundary=' + 'a0d738bcdb30449eb0d13f4b72c2897e'
 
     resp = client.simulate_post(
-        '/submit', headers={'Content-Type': content_type}, body=data)
+        '/submit', headers={'Content-Type': content_type}, body=data
+    )
 
     if max_headers_size < 142:
         assert resp.status_code == 400
@@ -786,7 +813,8 @@ def test_deserialize_part_media(client):
     resp = client.simulate_post(
         '/media',
         headers={'Content-Type': 'multipart/form-data; boundary=BOUNDARY'},
-        body=data)
+        body=data,
+    )
 
     assert resp.status_code == 200
     assert resp.json == [
@@ -805,15 +833,13 @@ def test_deserialize_custom_media(custom_client):
                 return '0x{:02x}'.format(first_byte[0])
             return ''
 
-        async def deserialize_async(self, stream, content_type,
-                                    content_length):
+        async def deserialize_async(self, stream, content_type, content_length):
             first_byte = await stream.read(1)
             if first_byte:
                 return '0x{:02x}'.format(first_byte[0])
             return ''
 
-    handlers = media.Handlers(
-        {'application/x-falcon-first-byte': FirstByteHandler()})
+    handlers = media.Handlers({'application/x-falcon-first-byte': FirstByteHandler()})
     client = custom_client({'media_handlers': handlers})
 
     data = (
@@ -831,7 +857,8 @@ def test_deserialize_custom_media(custom_client):
     resp = client.simulate_post(
         '/media',
         headers={'Content-Type': 'multipart/form-data; boundary=BOUNDARY'},
-        body=data)
+        body=data,
+    )
 
     assert resp.status_code == 200
     assert resp.json == ['', '0x48']
