@@ -23,11 +23,14 @@ def test_remote_addr_only(asgi):
         host='example.com',
         path='/access_route',
         headers={
-            'Forwarded': ('for=192.0.2.43, for="[2001:db8:cafe::17]:555",'
-                          'for="unknown", by=_hidden,for="\\"\\\\",'
-                          'for="198\\.51\\.100\\.17\\:1236";'
-                          'proto=https;host=example.com')
-        })
+            'Forwarded': (
+                'for=192.0.2.43, for="[2001:db8:cafe::17]:555",'
+                'for="unknown", by=_hidden,for="\\"\\\\",'
+                'for="198\\.51\\.100\\.17\\:1236";'
+                'proto=https;host=example.com'
+            )
+        },
+    )
 
     assert req.remote_addr == '127.0.0.1'
 
@@ -38,18 +41,28 @@ def test_rfc_forwarded(asgi):
         host='example.com',
         path='/access_route',
         headers={
-            'Forwarded': ('for=192.0.2.43,for=,'
-                          'for="[2001:db8:cafe::17]:555",'
-                          'for=x,'
-                          'for="unknown", by=_hidden,for="\\"\\\\",'
-                          'for="_don\\\"t_\\try_this\\\\at_home_\\42",'
-                          'for="198\\.51\\.100\\.17\\:1236";'
-                          'proto=https;host=example.com')
-        })
+            'Forwarded': (
+                'for=192.0.2.43,for=,'
+                'for="[2001:db8:cafe::17]:555",'
+                'for=x,'
+                'for="unknown", by=_hidden,for="\\"\\\\",'
+                'for="_don\\"t_\\try_this\\\\at_home_\\42",'
+                'for="198\\.51\\.100\\.17\\:1236";'
+                'proto=https;host=example.com'
+            )
+        },
+    )
 
-    compares = ['192.0.2.43', '2001:db8:cafe::17', 'x',
-                'unknown', '"\\', '_don"t_try_this\\at_home_42',
-                '198.51.100.17', '127.0.0.1']
+    compares = [
+        '192.0.2.43',
+        '2001:db8:cafe::17',
+        'x',
+        'unknown',
+        '"\\',
+        '_don"t_try_this\\at_home_42',
+        '198.51.100.17',
+        '127.0.0.1',
+    ]
 
     assert req.access_route == compares
 
@@ -59,12 +72,8 @@ def test_rfc_forwarded(asgi):
 
 def test_malformed_rfc_forwarded(asgi):
     req = create_req(
-        asgi,
-        host='example.com',
-        path='/access_route',
-        headers={
-            'Forwarded': 'for'
-        })
+        asgi, host='example.com', path='/access_route', headers={'Forwarded': 'for'}
+    )
 
     assert req.access_route == ['127.0.0.1']
 
@@ -75,10 +84,7 @@ def test_malformed_rfc_forwarded(asgi):
 @pytest.mark.parametrize('include_localhost', [True, False])
 def test_x_forwarded_for(asgi, include_localhost):
 
-    forwarded_for = (
-        '192.0.2.43, 2001:db8:cafe::17,'
-        'unknown, _hidden, 203.0.113.60'
-    )
+    forwarded_for = '192.0.2.43, 2001:db8:cafe::17,unknown, _hidden, 203.0.113.60'
 
     if include_localhost:
         forwarded_for += ', 127.0.0.1'
@@ -87,7 +93,7 @@ def test_x_forwarded_for(asgi, include_localhost):
         asgi,
         host='example.com',
         path='/access_route',
-        headers={'X-Forwarded-For': forwarded_for}
+        headers={'X-Forwarded-For': forwarded_for},
     )
 
     assert req.access_route == [
@@ -105,9 +111,8 @@ def test_x_real_ip(asgi):
         asgi,
         host='example.com',
         path='/access_route',
-        headers={
-            'X-Real-IP': '2001:db8:cafe::17'
-        })
+        headers={'X-Real-IP': '2001:db8:cafe::17'},
+    )
 
     assert req.access_route == ['2001:db8:cafe::17', '127.0.0.1']
 
