@@ -52,7 +52,6 @@ def test_app_missing():
 
 @pytest.mark.parametrize('asgi', [True, False])
 class TestRequestAttributes:
-
     def setup_method(self, method):
         asgi = self._item.callspec.getparam('asgi')
 
@@ -61,7 +60,7 @@ class TestRequestAttributes:
         self.headers = {
             'Content-Type': 'text/plain',
             'Content-Length': '4829',
-            'Authorization': ''
+            'Authorization': '',
         }
 
         self.root_path = '/test'
@@ -74,13 +73,12 @@ class TestRequestAttributes:
             port=8080,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
         self.req_noqs = create_req(
-            asgi,
-            root_path=self.root_path,
-            path='/hello',
-            headers=self.headers)
+            asgi, root_path=self.root_path, path='/hello', headers=self.headers
+        )
 
     def test_empty(self, asgi):
         assert self.req.auth is None
@@ -89,25 +87,15 @@ class TestRequestAttributes:
         assert self.req.host == testing.DEFAULT_HOST
 
     def test_subdomain(self, asgi):
-        req = create_req(
-            asgi,
-            host='com',
-            path='/hello',
-            headers=self.headers)
+        req = create_req(asgi, host='com', path='/hello', headers=self.headers)
         assert req.subdomain is None
 
-        req = create_req(
-            asgi,
-            host='example.com',
-            path='/hello',
-            headers=self.headers)
+        req = create_req(asgi, host='example.com', path='/hello', headers=self.headers)
         assert req.subdomain == 'example'
 
         req = create_req(
-            asgi,
-            host='highwire.example.com',
-            path='/hello',
-            headers=self.headers)
+            asgi, host='highwire.example.com', path='/hello', headers=self.headers
+        )
         assert req.subdomain == 'highwire'
 
         req = create_req(
@@ -115,16 +103,13 @@ class TestRequestAttributes:
             host='lb01.dfw01.example.com',
             port=8080,
             path='/hello',
-            headers=self.headers)
+            headers=self.headers,
+        )
         assert req.subdomain == 'lb01'
 
         # NOTE(kgriffs): Behavior for IP addresses is undefined,
         # so just make sure it doesn't blow up.
-        req = create_req(
-            asgi,
-            host='127.0.0.1',
-            path='/hello',
-            headers=self.headers)
+        req = create_req(asgi, host='127.0.0.1', path='/hello', headers=self.headers)
         assert type(req.subdomain) == str
 
         # NOTE(kgriffs): Test fallback to SERVER_NAME by using
@@ -135,7 +120,8 @@ class TestRequestAttributes:
             http_version='1.0',
             host='example.com',
             path='/hello',
-            headers=self.headers)
+            headers=self.headers,
+        )
         assert req.subdomain == 'example'
 
     def test_reconstruct_url(self, asgi):
@@ -154,11 +140,14 @@ class TestRequestAttributes:
         assert req.prefix == expected_prefix
         assert req.prefix == expected_prefix  # Check cached value
 
-    @pytest.mark.parametrize('test_path', [
-        '/hello_\u043f\u0440\u0438\u0432\u0435\u0442',
-        '/test/%E5%BB%B6%E5%AE%89',
-        '/test/%C3%A4%C3%B6%C3%BC%C3%9F%E2%82%AC',
-    ])
+    @pytest.mark.parametrize(
+        'test_path',
+        [
+            '/hello_\u043f\u0440\u0438\u0432\u0435\u0442',
+            '/test/%E5%BB%B6%E5%AE%89',
+            '/test/%C3%A4%C3%B6%C3%BC%C3%9F%E2%82%AC',
+        ],
+    )
     def test_nonlatin_path(self, asgi, test_path):
         # NOTE(kgriffs): When a request comes in, web servers decode
         # the path.  The decoded path may contain UTF-8 characters,
@@ -176,11 +165,7 @@ class TestRequestAttributes:
         #   path = tunnelled_path.encode('iso-8859-1').decode('utf-8', 'replace')
         #
 
-        req = create_req(
-            asgi,
-            host='com',
-            path=test_path,
-            headers=self.headers)
+        req = create_req(asgi, host='com', path=test_path, headers=self.headers)
 
         assert req.path == falcon.uri.decode(test_path)
 
@@ -195,34 +180,31 @@ class TestRequestAttributes:
         assert self.req.uri == uri
         assert self.req.uri == uri
 
-        uri_noqs = ('http://' + testing.DEFAULT_HOST + self.root_path + self.path)
+        uri_noqs = 'http://' + testing.DEFAULT_HOST + self.root_path + self.path
         assert self.req_noqs.uri == uri_noqs
 
     def test_uri_https(self, asgi):
         # =======================================================
         # Default port, implicit
         # =======================================================
-        req = create_req(
-            asgi, path='/hello', scheme='https')
-        uri = ('https://' + testing.DEFAULT_HOST + '/hello')
+        req = create_req(asgi, path='/hello', scheme='https')
+        uri = 'https://' + testing.DEFAULT_HOST + '/hello'
 
         assert req.uri == uri
 
         # =======================================================
         # Default port, explicit
         # =======================================================
-        req = create_req(
-            asgi, path='/hello', scheme='https', port=443)
-        uri = ('https://' + testing.DEFAULT_HOST + '/hello')
+        req = create_req(asgi, path='/hello', scheme='https', port=443)
+        uri = 'https://' + testing.DEFAULT_HOST + '/hello'
 
         assert req.uri == uri
 
         # =======================================================
         # Non-default port
         # =======================================================
-        req = create_req(
-            asgi, path='/hello', scheme='https', port=22)
-        uri = ('https://' + testing.DEFAULT_HOST + ':22/hello')
+        req = create_req(asgi, path='/hello', scheme='https', port=22)
+        uri = 'https://' + testing.DEFAULT_HOST + ':22/hello'
 
         assert req.uri == uri
 
@@ -237,10 +219,10 @@ class TestRequestAttributes:
             port=80,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
-        uri = ('http://' + testing.DEFAULT_HOST +
-               self.root_path + self.relative_uri)
+        uri = 'http://' + testing.DEFAULT_HOST + self.root_path + self.relative_uri
 
         assert req.uri == uri
 
@@ -254,10 +236,16 @@ class TestRequestAttributes:
             port=8080,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
-        uri = ('http://' + testing.DEFAULT_HOST + ':8080' +
-               self.root_path + self.relative_uri)
+        uri = (
+            'http://'
+            + testing.DEFAULT_HOST
+            + ':8080'
+            + self.root_path
+            + self.relative_uri
+        )
 
         assert req.uri == uri
 
@@ -272,10 +260,10 @@ class TestRequestAttributes:
             port=443,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
-        uri = ('https://' + testing.DEFAULT_HOST +
-               self.root_path + self.relative_uri)
+        uri = 'https://' + testing.DEFAULT_HOST + self.root_path + self.relative_uri
 
         assert req.uri == uri
 
@@ -290,10 +278,16 @@ class TestRequestAttributes:
             port=22,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
-        uri = ('https://' + testing.DEFAULT_HOST + ':22' +
-               self.root_path + self.relative_uri)
+        uri = (
+            'https://'
+            + testing.DEFAULT_HOST
+            + ':22'
+            + self.root_path
+            + self.relative_uri
+        )
 
         assert req.uri == uri
 
@@ -302,18 +296,14 @@ class TestRequestAttributes:
         assert self.req_noqs.relative_uri == self.root_path + self.path
 
         req_noapp = create_req(
-            asgi,
-            path='/hello',
-            query_string=self.qs,
-            headers=self.headers)
+            asgi, path='/hello', query_string=self.qs, headers=self.headers
+        )
 
         assert req_noapp.relative_uri == self.relative_uri
 
         req_noapp = create_req(
-            asgi,
-            path='/hello/',
-            query_string=self.qs,
-            headers=self.headers)
+            asgi, path='/hello/', query_string=self.qs, headers=self.headers
+        )
 
         relative_trailing_uri = self.path + '/?' + self.qs
         # NOTE(kgriffs): Call twice to check caching works
@@ -327,7 +317,8 @@ class TestRequestAttributes:
             options=options,
             path='/hello/',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
         assert req_noapp.relative_uri == '/hello/' + '?' + self.qs
 
@@ -438,9 +429,7 @@ class TestRequestAttributes:
         assert not req.client_accepts_json
         assert req.client_accepts_msgpack
 
-        headers = {
-            'Accept': 'application/json,application/xml,application/x-msgpack'
-        }
+        headers = {'Accept': 'application/json,application/xml,application/x-msgpack'}
         req = create_req(asgi, headers=headers)
         assert req.client_accepts_xml
         assert req.client_accepts_json
@@ -453,8 +442,7 @@ class TestRequestAttributes:
         assert preferred_type == 'application/xml'
 
         headers = {'Accept': '*/*'}
-        preferred_type = req.client_prefers(('application/xml',
-                                             'application/json'))
+        preferred_type = req.client_prefers(('application/xml', 'application/json'))
 
         # NOTE(kgriffs): If client doesn't care, "prefer" the first one
         assert preferred_type == 'application/xml'
@@ -520,18 +508,34 @@ class TestRequestAttributes:
             req.range
 
         headers = {'Range': 'bytes=-'}
-        expected_desc = ('The value provided for the "Range" header is '
-                         'invalid. The range offsets are missing.')
-        self._test_error_details(headers, 'range',
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value', expected_desc,
-                                 asgi)
+        expected_desc = (
+            'The value provided for the "Range" header is '
+            'invalid. The range offsets are missing.'
+        )
+        self._test_error_details(
+            headers,
+            'range',
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc,
+            asgi,
+        )
 
         headers = {'Range': 'bytes=--'}
         req = create_req(asgi, headers=headers)
         with pytest.raises(falcon.HTTPBadRequest):
             req.range
 
+        headers = {'Range': 'bytes=--1'}
+        req = create_req(asgi, headers=headers)
+        with pytest.raises(falcon.HTTPBadRequest):
+            req.range
+
+        headers = {'Range': 'bytes=--0'}
+        req = create_req(asgi, headers=headers)
+        with pytest.raises(falcon.HTTPBadRequest):
+            req.range
+
         headers = {'Range': 'bytes=-3-'}
         req = create_req(asgi, headers=headers)
         with pytest.raises(falcon.HTTPBadRequest):
@@ -542,6 +546,11 @@ class TestRequestAttributes:
         with pytest.raises(falcon.HTTPBadRequest):
             req.range
 
+        headers = {'Range': 'bytes=4-3'}
+        req = create_req(asgi, headers=headers)
+        with pytest.raises(falcon.HTTPBadRequest):
+            req.range
+
         headers = {'Range': 'bytes=3-3-4'}
         req = create_req(asgi, headers=headers)
         with pytest.raises(falcon.HTTPBadRequest):
@@ -583,31 +592,49 @@ class TestRequestAttributes:
             req.range
 
         headers = {'Range': 'bytes=x-y'}
-        expected_desc = ('The value provided for the "Range" header is '
-                         'invalid. It must be a range formatted '
-                         'according to RFC 7233.')
-        self._test_error_details(headers, 'range',
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value', expected_desc,
-                                 asgi)
+        expected_desc = (
+            'The value provided for the "Range" header is '
+            'invalid. It must be a range formatted '
+            'according to RFC 7233.'
+        )
+        self._test_error_details(
+            headers,
+            'range',
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc,
+            asgi,
+        )
 
         headers = {'Range': 'bytes=0-0,-1'}
-        expected_desc = ('The value provided for the "Range" '
-                         'header is invalid. The value must be a '
-                         'continuous range.')
-        self._test_error_details(headers, 'range',
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value', expected_desc,
-                                 asgi)
+        expected_desc = (
+            'The value provided for the "Range" '
+            'header is invalid. The value must be a '
+            'continuous range.'
+        )
+        self._test_error_details(
+            headers,
+            'range',
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc,
+            asgi,
+        )
 
         headers = {'Range': '10-'}
-        expected_desc = ('The value provided for the "Range" '
-                         'header is invalid. The value must be '
-                         "prefixed with a range unit, e.g. 'bytes='")
-        self._test_error_details(headers, 'range',
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value', expected_desc,
-                                 asgi)
+        expected_desc = (
+            'The value provided for the "Range" '
+            'header is invalid. The value must be '
+            "prefixed with a range unit, e.g. 'bytes='"
+        )
+        self._test_error_details(
+            headers,
+            'range',
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc,
+            asgi,
+        )
 
     def test_missing_attribute_header(self, asgi):
         req = create_req(asgi)
@@ -627,29 +654,44 @@ class TestRequestAttributes:
 
     def test_bogus_content_length_nan(self, asgi):
         headers = {'content-length': 'fuzzy-bunnies'}
-        expected_desc = ('The value provided for the '
-                         '"Content-Length" header is invalid. The value '
-                         'of the header must be a number.')
-        self._test_error_details(headers, 'content_length',
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value', expected_desc,
-                                 asgi)
+        expected_desc = (
+            'The value provided for the '
+            '"Content-Length" header is invalid. The value '
+            'of the header must be a number.'
+        )
+        self._test_error_details(
+            headers,
+            'content_length',
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc,
+            asgi,
+        )
 
     def test_bogus_content_length_neg(self, asgi):
         headers = {'content-length': '-1'}
-        expected_desc = ('The value provided for the "Content-Length" '
-                         'header is invalid. The value of the header '
-                         'must be a positive number.')
-        self._test_error_details(headers, 'content_length',
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value', expected_desc,
-                                 asgi)
+        expected_desc = (
+            'The value provided for the "Content-Length" '
+            'header is invalid. The value of the header '
+            'must be a positive number.'
+        )
+        self._test_error_details(
+            headers,
+            'content_length',
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc,
+            asgi,
+        )
 
-    @pytest.mark.parametrize('header,attr', [
-        ('Date', 'date'),
-        ('If-Modified-Since', 'if_modified_since'),
-        ('If-Unmodified-Since', 'if_unmodified_since'),
-    ])
+    @pytest.mark.parametrize(
+        'header,attr',
+        [
+            ('Date', 'date'),
+            ('If-Modified-Since', 'if_modified_since'),
+            ('If-Unmodified-Since', 'if_unmodified_since'),
+        ],
+    )
     def test_date(self, asgi, header, attr):
         date = datetime.datetime(2013, 4, 4, 5, 19, 18)
         date_str = 'Thu, 04 Apr 2013 05:19:18 GMT'
@@ -658,46 +700,72 @@ class TestRequestAttributes:
         req = create_req(asgi, headers=headers)
         assert getattr(req, attr) == date
 
-    @pytest.mark.parametrize('header,attr', [
-        ('Date', 'date'),
-        ('If-Modified-Since', 'if_modified_since'),
-        ('If-Unmodified-Since', 'if_unmodified_since'),
-    ])
+    @pytest.mark.parametrize(
+        'header,attr',
+        [
+            ('Date', 'date'),
+            ('If-Modified-Since', 'if_modified_since'),
+            ('If-Unmodified-Since', 'if_unmodified_since'),
+        ],
+    )
     def test_date_invalid(self, asgi, header, attr):
 
         # Date formats don't conform to RFC 1123
         headers = {header: 'Thu, 04 Apr 2013'}
-        expected_desc = ('The value provided for the "{}" '
-                         'header is invalid. It must be formatted '
-                         'according to RFC 7231, Section 7.1.1.1')
+        expected_desc = (
+            'The value provided for the "{}" '
+            'header is invalid. It must be formatted '
+            'according to RFC 7231, Section 7.1.1.1'
+        )
 
-        self._test_error_details(headers, attr,
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value',
-                                 expected_desc.format(header),
-                                 asgi)
+        self._test_error_details(
+            headers,
+            attr,
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc.format(header),
+            asgi,
+        )
 
         headers = {header: ''}
-        self._test_error_details(headers, attr,
-                                 falcon.HTTPInvalidHeader,
-                                 'Invalid header value',
-                                 expected_desc.format(header),
-                                 asgi)
+        self._test_error_details(
+            headers,
+            attr,
+            falcon.HTTPInvalidHeader,
+            'Invalid header value',
+            expected_desc.format(header),
+            asgi,
+        )
 
-    @pytest.mark.parametrize('attr', ('date', 'if_modified_since', 'if_unmodified_since'))
+    @pytest.mark.parametrize(
+        'attr', ('date', 'if_modified_since', 'if_unmodified_since')
+    )
     def test_date_missing(self, asgi, attr):
         req = create_req(asgi)
         assert getattr(req, attr) is None
 
-    @pytest.mark.parametrize('name,value,attr,default', [
-        ('Accept', 'x-falcon', 'accept', '*/*'),
-        ('Authorization', 'HMAC_SHA1 c590afa9bb59191ffab30f223791e82d3fd3e3af', 'auth', None),
-        ('Content-Type', 'text/plain', 'content_type', None),
-        ('Expect', '100-continue', 'expect', None),
-        ('If-Range', 'Wed, 21 Oct 2015 07:28:00 GMT', 'if_range', None),
-        ('User-Agent', 'testing/3.0', 'user_agent', 'falcon-client/' + falcon.__version__),
-        ('Referer', 'https://www.google.com/', 'referer', None),
-    ])
+    @pytest.mark.parametrize(
+        'name,value,attr,default',
+        [
+            ('Accept', 'x-falcon', 'accept', '*/*'),
+            (
+                'Authorization',
+                'HMAC_SHA1 c590afa9bb59191ffab30f223791e82d3fd3e3af',
+                'auth',
+                None,
+            ),
+            ('Content-Type', 'text/plain', 'content_type', None),
+            ('Expect', '100-continue', 'expect', None),
+            ('If-Range', 'Wed, 21 Oct 2015 07:28:00 GMT', 'if_range', None),
+            (
+                'User-Agent',
+                'testing/3.0',
+                'user_agent',
+                'falcon-client/' + falcon.__version__,
+            ),
+            ('Referer', 'https://www.google.com/', 'referer', None),
+        ],
+    )
     def test_attribute_headers(self, asgi, name, value, attr, default):
         headers = {name: value}
         req = create_req(asgi, headers=headers)
@@ -734,7 +802,8 @@ class TestRequestAttributes:
             root_path=self.root_path,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
         assert req.port == port
 
@@ -748,14 +817,15 @@ class TestRequestAttributes:
             root_path=self.root_path,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
         assert req.scheme == scheme
         assert req.port == 443
 
     @pytest.mark.parametrize(
         'http_version, set_forwarded_proto',
-        list(itertools.product(_HTTP_VERSIONS, [True, False]))
+        list(itertools.product(_HTTP_VERSIONS, [True, False])),
     )
     def test_scheme_http(self, asgi, http_version, set_forwarded_proto):
         scheme = 'http'
@@ -773,7 +843,8 @@ class TestRequestAttributes:
             root_path=self.root_path,
             path='/hello',
             query_string=self.qs,
-            headers=headers)
+            headers=headers,
+        )
 
         assert req.scheme == scheme
         assert req.port == 80
@@ -791,7 +862,8 @@ class TestRequestAttributes:
             root_path=self.root_path,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
         assert req.netloc == 'falconframework.org'
 
@@ -804,7 +876,8 @@ class TestRequestAttributes:
             root_path=self.root_path,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
         assert req.netloc == 'falconframework.org:8080'
 
@@ -821,7 +894,8 @@ class TestRequestAttributes:
             root_path=self.root_path,
             path='/hello',
             query_string=self.qs,
-            headers=self.headers)
+            headers=self.headers,
+        )
 
         assert req.port == port
         assert req.netloc == '{}:{}'.format(host, port)
@@ -834,108 +908,64 @@ class TestRequestAttributes:
         req = create_req(asgi, root_path='')
         assert req.app == ''
 
-    @pytest.mark.parametrize('etag,expected_value', [
-        ('', None),
-        (' ', None),
-        ('   ', None),
-        ('\t', None),
-        (' \t', None),
-        (',', None),
-        (',,', None),
-        (',, ', None),
-        (', , ', None),
-        ('*', ['*']),
-        (
-            'W/"67ab43"',
-            [_make_etag('67ab43', is_weak=True)]
-        ),
-        (
-            'w/"67ab43"',
-            [_make_etag('67ab43', is_weak=True)]
-        ),
-        (
-            ' w/"67ab43"',
-            [_make_etag('67ab43', is_weak=True)]
-        ),
-        (
-            'w/"67ab43" ',
-            [_make_etag('67ab43', is_weak=True)]
-        ),
-        (
-            'w/"67ab43 " ',
-            [_make_etag('67ab43 ', is_weak=True)]
-        ),
-        (
-            '"67ab43"',
-            [_make_etag('67ab43')]
-        ),
-        (
-            ' "67ab43"',
-            [_make_etag('67ab43')]
-        ),
-        (
-            ' "67ab43" ',
-            [_make_etag('67ab43')]
-        ),
-        (
-            '"67ab43" ',
-            [_make_etag('67ab43')]
-        ),
-        (
-            '" 67ab43" ',
-            [_make_etag(' 67ab43')]
-        ),
-        (
-            '67ab43"',
-            [_make_etag('67ab43"')]
-        ),
-        (
-            '"67ab43',
-            [_make_etag('"67ab43')]
-        ),
-        (
-            '67ab43',
-            [_make_etag('67ab43')]
-        ),
-        (
-            '67ab43 ',
-            [_make_etag('67ab43')]
-        ),
-        (
-            '  67ab43 ',
-            [_make_etag('67ab43')]
-        ),
-        (
-            '  67ab43',
-            [_make_etag('67ab43')]
-        ),
-        (
-            # NOTE(kgriffs): To simplify parsing and improve performance, we
-            #   do not attempt to handle unquoted entity-tags when there is
-            #   a list; it is non-standard anyway, and has been since 1999.
-            'W/"67ab43", "54ed21", junk"F9,22", junk "41, 7F", unquoted, w/"22, 41, 7F", "", W/""',
-            [
-                _make_etag('67ab43', is_weak=True),
-                _make_etag('54ed21'),
-
-                # NOTE(kgriffs): Test that the ETag initializer defaults to
-                #   is_weak == False
-                ETag('F9,22'),
-
-                _make_etag('41, 7F'),
-                _make_etag('22, 41, 7F', is_weak=True),
-
-                # NOTE(kgriffs): According to the grammar in RFC 7232, zero
-                #  etagc's is acceptable.
-                _make_etag(''),
-                _make_etag('', is_weak=True),
-            ]
-        ),
-    ])
-    @pytest.mark.parametrize('name,attr', [
-        ('If-Match', 'if_match'),
-        ('If-None-Match', 'if_none_match'),
-    ])
+    @pytest.mark.parametrize(
+        'etag,expected_value',
+        [
+            ('', None),
+            (' ', None),
+            ('   ', None),
+            ('\t', None),
+            (' \t', None),
+            (',', None),
+            (',,', None),
+            (',, ', None),
+            (', , ', None),
+            ('*', ['*']),
+            ('W/"67ab43"', [_make_etag('67ab43', is_weak=True)]),
+            ('w/"67ab43"', [_make_etag('67ab43', is_weak=True)]),
+            (' w/"67ab43"', [_make_etag('67ab43', is_weak=True)]),
+            ('w/"67ab43" ', [_make_etag('67ab43', is_weak=True)]),
+            ('w/"67ab43 " ', [_make_etag('67ab43 ', is_weak=True)]),
+            ('"67ab43"', [_make_etag('67ab43')]),
+            (' "67ab43"', [_make_etag('67ab43')]),
+            (' "67ab43" ', [_make_etag('67ab43')]),
+            ('"67ab43" ', [_make_etag('67ab43')]),
+            ('" 67ab43" ', [_make_etag(' 67ab43')]),
+            ('67ab43"', [_make_etag('67ab43"')]),
+            ('"67ab43', [_make_etag('"67ab43')]),
+            ('67ab43', [_make_etag('67ab43')]),
+            ('67ab43 ', [_make_etag('67ab43')]),
+            ('  67ab43 ', [_make_etag('67ab43')]),
+            ('  67ab43', [_make_etag('67ab43')]),
+            (
+                # NOTE(kgriffs): To simplify parsing and improve performance, we
+                #   do not attempt to handle unquoted entity-tags when there is
+                #   a list; it is non-standard anyway, and has been since 1999.
+                'W/"67ab43", "54ed21", junk"F9,22", junk "41, 7F", '
+                'unquoted, w/"22, 41, 7F", "", W/""',
+                [
+                    _make_etag('67ab43', is_weak=True),
+                    _make_etag('54ed21'),
+                    # NOTE(kgriffs): Test that the ETag initializer defaults to
+                    #   is_weak == False
+                    ETag('F9,22'),
+                    _make_etag('41, 7F'),
+                    _make_etag('22, 41, 7F', is_weak=True),
+                    # NOTE(kgriffs): According to the grammar in RFC 7232, zero
+                    #  etagc's is acceptable.
+                    _make_etag(''),
+                    _make_etag('', is_weak=True),
+                ],
+            ),
+        ],
+    )
+    @pytest.mark.parametrize(
+        'name,attr',
+        [
+            ('If-Match', 'if_match'),
+            ('If-None-Match', 'if_none_match'),
+        ],
+    )
     def test_etag(self, asgi, name, attr, etag, expected_value):
         headers = {name: etag}
         req = create_req(asgi, headers=headers)
@@ -974,8 +1004,9 @@ class TestRequestAttributes:
     # Helpers
     # -------------------------------------------------------------------------
 
-    def _test_error_details(self, headers, attr_name,
-                            error_type, title, description, asgi):
+    def _test_error_details(
+        self, headers, attr_name, error_type, title, description, asgi
+    ):
         req = create_req(asgi, headers=headers)
 
         try:
