@@ -18,7 +18,6 @@ def client():
 
 
 class LoggerResource:
-
     def on_get(self, req, resp):
         req.log_error(unicode_message)
 
@@ -27,19 +26,18 @@ class LoggerResource:
 
 
 class TestWSGIError:
-
     def setup_method(self, method):
         self.wsgierrors_buffer = io.BytesIO()
 
         # Simulate Gunicorn's behavior under Python 3
-        self.wsgierrors = io.TextIOWrapper(self.wsgierrors_buffer,
-                                           line_buffering=True,
-                                           encoding='utf-8')
+        self.wsgierrors = io.TextIOWrapper(
+            self.wsgierrors_buffer, line_buffering=True, encoding='utf-8'
+        )
 
     def test_responder_logged_bytestring(self, client):
-        client.simulate_request(path='/logger',
-                                wsgierrors=self.wsgierrors,
-                                query_string='amount=10')
+        client.simulate_request(
+            path='/logger', wsgierrors=self.wsgierrors, query_string='amount=10'
+        )
 
         log = self.wsgierrors_buffer.getvalue()
 
